entity

package
v0.0.0-...-e8af2e3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 16, 2026 License: AGPL-3.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the entity type in the database.
	Label = "entity"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// FieldName holds the string denoting the name field in the database.
	FieldName = "name"
	// FieldDescription holds the string denoting the description field in the database.
	FieldDescription = "description"
	// FieldImportRef holds the string denoting the import_ref field in the database.
	FieldImportRef = "import_ref"
	// FieldNotes holds the string denoting the notes field in the database.
	FieldNotes = "notes"
	// FieldQuantity holds the string denoting the quantity field in the database.
	FieldQuantity = "quantity"
	// FieldInsured holds the string denoting the insured field in the database.
	FieldInsured = "insured"
	// FieldArchived holds the string denoting the archived field in the database.
	FieldArchived = "archived"
	// FieldAssetID holds the string denoting the asset_id field in the database.
	FieldAssetID = "asset_id"
	// FieldSyncChildEntityLocations holds the string denoting the sync_child_entity_locations field in the database.
	FieldSyncChildEntityLocations = "sync_child_entity_locations"
	// FieldSerialNumber holds the string denoting the serial_number field in the database.
	FieldSerialNumber = "serial_number"
	// FieldModelNumber holds the string denoting the model_number field in the database.
	FieldModelNumber = "model_number"
	// FieldManufacturer holds the string denoting the manufacturer field in the database.
	FieldManufacturer = "manufacturer"
	// FieldLifetimeWarranty holds the string denoting the lifetime_warranty field in the database.
	FieldLifetimeWarranty = "lifetime_warranty"
	// FieldWarrantyExpires holds the string denoting the warranty_expires field in the database.
	FieldWarrantyExpires = "warranty_expires"
	// FieldWarrantyDetails holds the string denoting the warranty_details field in the database.
	FieldWarrantyDetails = "warranty_details"
	// FieldPurchaseDate holds the string denoting the purchase_date field in the database.
	FieldPurchaseDate = "purchase_date"
	// FieldPurchaseFrom holds the string denoting the purchase_from field in the database.
	FieldPurchaseFrom = "purchase_from"
	// FieldPurchasePrice holds the string denoting the purchase_price field in the database.
	FieldPurchasePrice = "purchase_price"
	// FieldSoldDate holds the string denoting the sold_date field in the database.
	FieldSoldDate = "sold_date"
	// FieldSoldTo holds the string denoting the sold_to field in the database.
	FieldSoldTo = "sold_to"
	// FieldSoldPrice holds the string denoting the sold_price field in the database.
	FieldSoldPrice = "sold_price"
	// FieldSoldNotes holds the string denoting the sold_notes field in the database.
	FieldSoldNotes = "sold_notes"
	// EdgeGroup holds the string denoting the group edge name in mutations.
	EdgeGroup = "group"
	// EdgeParent holds the string denoting the parent edge name in mutations.
	EdgeParent = "parent"
	// EdgeChildren holds the string denoting the children edge name in mutations.
	EdgeChildren = "children"
	// EdgeTag holds the string denoting the tag edge name in mutations.
	EdgeTag = "tag"
	// EdgeEntityType holds the string denoting the entity_type edge name in mutations.
	EdgeEntityType = "entity_type"
	// EdgeFields holds the string denoting the fields edge name in mutations.
	EdgeFields = "fields"
	// EdgeMaintenanceEntries holds the string denoting the maintenance_entries edge name in mutations.
	EdgeMaintenanceEntries = "maintenance_entries"
	// EdgeAttachments holds the string denoting the attachments edge name in mutations.
	EdgeAttachments = "attachments"
	// Table holds the table name of the entity in the database.
	Table = "entities"
	// GroupTable is the table that holds the group relation/edge.
	GroupTable = "entities"
	// GroupInverseTable is the table name for the Group entity.
	// It exists in this package in order to avoid circular dependency with the "group" package.
	GroupInverseTable = "groups"
	// GroupColumn is the table column denoting the group relation/edge.
	GroupColumn = "group_entities"
	// ParentTable is the table that holds the parent relation/edge.
	ParentTable = "entities"
	// ParentColumn is the table column denoting the parent relation/edge.
	ParentColumn = "entity_children"
	// ChildrenTable is the table that holds the children relation/edge.
	ChildrenTable = "entities"
	// ChildrenColumn is the table column denoting the children relation/edge.
	ChildrenColumn = "entity_children"
	// TagTable is the table that holds the tag relation/edge. The primary key declared below.
	TagTable = "tag_entities"
	// TagInverseTable is the table name for the Tag entity.
	// It exists in this package in order to avoid circular dependency with the "tag" package.
	TagInverseTable = "tags"
	// EntityTypeTable is the table that holds the entity_type relation/edge.
	EntityTypeTable = "entities"
	// EntityTypeInverseTable is the table name for the EntityType entity.
	// It exists in this package in order to avoid circular dependency with the "entitytype" package.
	EntityTypeInverseTable = "entity_types"
	// EntityTypeColumn is the table column denoting the entity_type relation/edge.
	EntityTypeColumn = "entity_type_entities"
	// FieldsTable is the table that holds the fields relation/edge.
	FieldsTable = "entity_fields"
	// FieldsInverseTable is the table name for the EntityField entity.
	// It exists in this package in order to avoid circular dependency with the "entityfield" package.
	FieldsInverseTable = "entity_fields"
	// FieldsColumn is the table column denoting the fields relation/edge.
	FieldsColumn = "entity_fields"
	// MaintenanceEntriesTable is the table that holds the maintenance_entries relation/edge.
	MaintenanceEntriesTable = "maintenance_entries"
	// MaintenanceEntriesInverseTable is the table name for the MaintenanceEntry entity.
	// It exists in this package in order to avoid circular dependency with the "maintenanceentry" package.
	MaintenanceEntriesInverseTable = "maintenance_entries"
	// MaintenanceEntriesColumn is the table column denoting the maintenance_entries relation/edge.
	MaintenanceEntriesColumn = "entity_id"
	// AttachmentsTable is the table that holds the attachments relation/edge.
	AttachmentsTable = "attachments"
	// AttachmentsInverseTable is the table name for the Attachment entity.
	// It exists in this package in order to avoid circular dependency with the "attachment" package.
	AttachmentsInverseTable = "attachments"
	// AttachmentsColumn is the table column denoting the attachments relation/edge.
	AttachmentsColumn = "entity_attachments"
)

Variables

var (
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// NameValidator is a validator for the "name" field. It is called by the builders before save.
	NameValidator func(string) error
	// DescriptionValidator is a validator for the "description" field. It is called by the builders before save.
	DescriptionValidator func(string) error
	// ImportRefValidator is a validator for the "import_ref" field. It is called by the builders before save.
	ImportRefValidator func(string) error
	// NotesValidator is a validator for the "notes" field. It is called by the builders before save.
	NotesValidator func(string) error
	// DefaultQuantity holds the default value on creation for the "quantity" field.
	DefaultQuantity float64
	// DefaultInsured holds the default value on creation for the "insured" field.
	DefaultInsured bool
	// DefaultArchived holds the default value on creation for the "archived" field.
	DefaultArchived bool
	// DefaultAssetID holds the default value on creation for the "asset_id" field.
	DefaultAssetID int64
	// DefaultSyncChildEntityLocations holds the default value on creation for the "sync_child_entity_locations" field.
	DefaultSyncChildEntityLocations bool
	// SerialNumberValidator is a validator for the "serial_number" field. It is called by the builders before save.
	SerialNumberValidator func(string) error
	// ModelNumberValidator is a validator for the "model_number" field. It is called by the builders before save.
	ModelNumberValidator func(string) error
	// ManufacturerValidator is a validator for the "manufacturer" field. It is called by the builders before save.
	ManufacturerValidator func(string) error
	// DefaultLifetimeWarranty holds the default value on creation for the "lifetime_warranty" field.
	DefaultLifetimeWarranty bool
	// WarrantyDetailsValidator is a validator for the "warranty_details" field. It is called by the builders before save.
	WarrantyDetailsValidator func(string) error
	// DefaultPurchasePrice holds the default value on creation for the "purchase_price" field.
	DefaultPurchasePrice float64
	// DefaultSoldPrice holds the default value on creation for the "sold_price" field.
	DefaultSoldPrice float64
	// SoldNotesValidator is a validator for the "sold_notes" field. It is called by the builders before save.
	SoldNotesValidator func(string) error
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() uuid.UUID
)

Columns holds all SQL columns for entity fields.

var ForeignKeys = []string{
	"entity_children",
	"entity_type_entities",
	"group_entities",
}

ForeignKeys holds the SQL foreign-keys that are owned by the "entities" table and are not defined as standalone fields in the schema.

var (
	// TagPrimaryKey and TagColumn2 are the table columns denoting the
	// primary key for the tag relation (M2M).
	TagPrimaryKey = []string{"tag_id", "entity_id"}
)

Functions

func And

func And(predicates ...predicate.Entity) predicate.Entity

And groups predicates with the AND operator between them.

func Archived

func Archived(v bool) predicate.Entity

Archived applies equality check predicate on the "archived" field. It's identical to ArchivedEQ.

func ArchivedEQ

func ArchivedEQ(v bool) predicate.Entity

ArchivedEQ applies the EQ predicate on the "archived" field.

func ArchivedNEQ

func ArchivedNEQ(v bool) predicate.Entity

ArchivedNEQ applies the NEQ predicate on the "archived" field.

func AssetID

func AssetID(v int64) predicate.Entity

AssetID applies equality check predicate on the "asset_id" field. It's identical to AssetIDEQ.

func AssetIDEQ

func AssetIDEQ(v int64) predicate.Entity

AssetIDEQ applies the EQ predicate on the "asset_id" field.

func AssetIDGT

func AssetIDGT(v int64) predicate.Entity

AssetIDGT applies the GT predicate on the "asset_id" field.

func AssetIDGTE

func AssetIDGTE(v int64) predicate.Entity

AssetIDGTE applies the GTE predicate on the "asset_id" field.

func AssetIDIn

func AssetIDIn(vs ...int64) predicate.Entity

AssetIDIn applies the In predicate on the "asset_id" field.

func AssetIDLT

func AssetIDLT(v int64) predicate.Entity

AssetIDLT applies the LT predicate on the "asset_id" field.

func AssetIDLTE

func AssetIDLTE(v int64) predicate.Entity

AssetIDLTE applies the LTE predicate on the "asset_id" field.

func AssetIDNEQ

func AssetIDNEQ(v int64) predicate.Entity

AssetIDNEQ applies the NEQ predicate on the "asset_id" field.

func AssetIDNotIn

func AssetIDNotIn(vs ...int64) predicate.Entity

AssetIDNotIn applies the NotIn predicate on the "asset_id" field.

func CreatedAt

func CreatedAt(v time.Time) predicate.Entity

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.Entity

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.Entity

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.Entity

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.Entity

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.Entity

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.Entity

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.Entity

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.Entity

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func Description

func Description(v string) predicate.Entity

Description applies equality check predicate on the "description" field. It's identical to DescriptionEQ.

func DescriptionContains

func DescriptionContains(v string) predicate.Entity

DescriptionContains applies the Contains predicate on the "description" field.

func DescriptionContainsFold

func DescriptionContainsFold(v string) predicate.Entity

DescriptionContainsFold applies the ContainsFold predicate on the "description" field.

func DescriptionEQ

func DescriptionEQ(v string) predicate.Entity

DescriptionEQ applies the EQ predicate on the "description" field.

func DescriptionEqualFold

func DescriptionEqualFold(v string) predicate.Entity

DescriptionEqualFold applies the EqualFold predicate on the "description" field.

func DescriptionGT

func DescriptionGT(v string) predicate.Entity

DescriptionGT applies the GT predicate on the "description" field.

func DescriptionGTE

func DescriptionGTE(v string) predicate.Entity

DescriptionGTE applies the GTE predicate on the "description" field.

func DescriptionHasPrefix

func DescriptionHasPrefix(v string) predicate.Entity

DescriptionHasPrefix applies the HasPrefix predicate on the "description" field.

func DescriptionHasSuffix

func DescriptionHasSuffix(v string) predicate.Entity

DescriptionHasSuffix applies the HasSuffix predicate on the "description" field.

func DescriptionIn

func DescriptionIn(vs ...string) predicate.Entity

DescriptionIn applies the In predicate on the "description" field.

func DescriptionIsNil

func DescriptionIsNil() predicate.Entity

DescriptionIsNil applies the IsNil predicate on the "description" field.

func DescriptionLT

func DescriptionLT(v string) predicate.Entity

DescriptionLT applies the LT predicate on the "description" field.

func DescriptionLTE

func DescriptionLTE(v string) predicate.Entity

DescriptionLTE applies the LTE predicate on the "description" field.

func DescriptionNEQ

func DescriptionNEQ(v string) predicate.Entity

DescriptionNEQ applies the NEQ predicate on the "description" field.

func DescriptionNotIn

func DescriptionNotIn(vs ...string) predicate.Entity

DescriptionNotIn applies the NotIn predicate on the "description" field.

func DescriptionNotNil

func DescriptionNotNil() predicate.Entity

DescriptionNotNil applies the NotNil predicate on the "description" field.

func HasAttachments

func HasAttachments() predicate.Entity

HasAttachments applies the HasEdge predicate on the "attachments" edge.

func HasAttachmentsWith

func HasAttachmentsWith(preds ...predicate.Attachment) predicate.Entity

HasAttachmentsWith applies the HasEdge predicate on the "attachments" edge with a given conditions (other predicates).

func HasChildren

func HasChildren() predicate.Entity

HasChildren applies the HasEdge predicate on the "children" edge.

func HasChildrenWith

func HasChildrenWith(preds ...predicate.Entity) predicate.Entity

HasChildrenWith applies the HasEdge predicate on the "children" edge with a given conditions (other predicates).

func HasEntityType

func HasEntityType() predicate.Entity

HasEntityType applies the HasEdge predicate on the "entity_type" edge.

func HasEntityTypeWith

func HasEntityTypeWith(preds ...predicate.EntityType) predicate.Entity

HasEntityTypeWith applies the HasEdge predicate on the "entity_type" edge with a given conditions (other predicates).

func HasFields

func HasFields() predicate.Entity

HasFields applies the HasEdge predicate on the "fields" edge.

func HasFieldsWith

func HasFieldsWith(preds ...predicate.EntityField) predicate.Entity

HasFieldsWith applies the HasEdge predicate on the "fields" edge with a given conditions (other predicates).

func HasGroup

func HasGroup() predicate.Entity

HasGroup applies the HasEdge predicate on the "group" edge.

func HasGroupWith

func HasGroupWith(preds ...predicate.Group) predicate.Entity

HasGroupWith applies the HasEdge predicate on the "group" edge with a given conditions (other predicates).

func HasMaintenanceEntries

func HasMaintenanceEntries() predicate.Entity

HasMaintenanceEntries applies the HasEdge predicate on the "maintenance_entries" edge.

func HasMaintenanceEntriesWith

func HasMaintenanceEntriesWith(preds ...predicate.MaintenanceEntry) predicate.Entity

HasMaintenanceEntriesWith applies the HasEdge predicate on the "maintenance_entries" edge with a given conditions (other predicates).

func HasParent

func HasParent() predicate.Entity

HasParent applies the HasEdge predicate on the "parent" edge.

func HasParentWith

func HasParentWith(preds ...predicate.Entity) predicate.Entity

HasParentWith applies the HasEdge predicate on the "parent" edge with a given conditions (other predicates).

func HasTag

func HasTag() predicate.Entity

HasTag applies the HasEdge predicate on the "tag" edge.

func HasTagWith

func HasTagWith(preds ...predicate.Tag) predicate.Entity

HasTagWith applies the HasEdge predicate on the "tag" edge with a given conditions (other predicates).

func ID

func ID(id uuid.UUID) predicate.Entity

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id uuid.UUID) predicate.Entity

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id uuid.UUID) predicate.Entity

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id uuid.UUID) predicate.Entity

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uuid.UUID) predicate.Entity

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id uuid.UUID) predicate.Entity

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id uuid.UUID) predicate.Entity

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id uuid.UUID) predicate.Entity

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uuid.UUID) predicate.Entity

IDNotIn applies the NotIn predicate on the ID field.

func ImportRef

func ImportRef(v string) predicate.Entity

ImportRef applies equality check predicate on the "import_ref" field. It's identical to ImportRefEQ.

func ImportRefContains

func ImportRefContains(v string) predicate.Entity

ImportRefContains applies the Contains predicate on the "import_ref" field.

func ImportRefContainsFold

func ImportRefContainsFold(v string) predicate.Entity

ImportRefContainsFold applies the ContainsFold predicate on the "import_ref" field.

func ImportRefEQ

func ImportRefEQ(v string) predicate.Entity

ImportRefEQ applies the EQ predicate on the "import_ref" field.

func ImportRefEqualFold

func ImportRefEqualFold(v string) predicate.Entity

ImportRefEqualFold applies the EqualFold predicate on the "import_ref" field.

func ImportRefGT

func ImportRefGT(v string) predicate.Entity

ImportRefGT applies the GT predicate on the "import_ref" field.

func ImportRefGTE

func ImportRefGTE(v string) predicate.Entity

ImportRefGTE applies the GTE predicate on the "import_ref" field.

func ImportRefHasPrefix

func ImportRefHasPrefix(v string) predicate.Entity

ImportRefHasPrefix applies the HasPrefix predicate on the "import_ref" field.

func ImportRefHasSuffix

func ImportRefHasSuffix(v string) predicate.Entity

ImportRefHasSuffix applies the HasSuffix predicate on the "import_ref" field.

func ImportRefIn

func ImportRefIn(vs ...string) predicate.Entity

ImportRefIn applies the In predicate on the "import_ref" field.

func ImportRefIsNil

func ImportRefIsNil() predicate.Entity

ImportRefIsNil applies the IsNil predicate on the "import_ref" field.

func ImportRefLT

func ImportRefLT(v string) predicate.Entity

ImportRefLT applies the LT predicate on the "import_ref" field.

func ImportRefLTE

func ImportRefLTE(v string) predicate.Entity

ImportRefLTE applies the LTE predicate on the "import_ref" field.

func ImportRefNEQ

func ImportRefNEQ(v string) predicate.Entity

ImportRefNEQ applies the NEQ predicate on the "import_ref" field.

func ImportRefNotIn

func ImportRefNotIn(vs ...string) predicate.Entity

ImportRefNotIn applies the NotIn predicate on the "import_ref" field.

func ImportRefNotNil

func ImportRefNotNil() predicate.Entity

ImportRefNotNil applies the NotNil predicate on the "import_ref" field.

func Insured

func Insured(v bool) predicate.Entity

Insured applies equality check predicate on the "insured" field. It's identical to InsuredEQ.

func InsuredEQ

func InsuredEQ(v bool) predicate.Entity

InsuredEQ applies the EQ predicate on the "insured" field.

func InsuredNEQ

func InsuredNEQ(v bool) predicate.Entity

InsuredNEQ applies the NEQ predicate on the "insured" field.

func LifetimeWarranty

func LifetimeWarranty(v bool) predicate.Entity

LifetimeWarranty applies equality check predicate on the "lifetime_warranty" field. It's identical to LifetimeWarrantyEQ.

func LifetimeWarrantyEQ

func LifetimeWarrantyEQ(v bool) predicate.Entity

LifetimeWarrantyEQ applies the EQ predicate on the "lifetime_warranty" field.

func LifetimeWarrantyNEQ

func LifetimeWarrantyNEQ(v bool) predicate.Entity

LifetimeWarrantyNEQ applies the NEQ predicate on the "lifetime_warranty" field.

func Manufacturer

func Manufacturer(v string) predicate.Entity

Manufacturer applies equality check predicate on the "manufacturer" field. It's identical to ManufacturerEQ.

func ManufacturerContains

func ManufacturerContains(v string) predicate.Entity

ManufacturerContains applies the Contains predicate on the "manufacturer" field.

func ManufacturerContainsFold

func ManufacturerContainsFold(v string) predicate.Entity

ManufacturerContainsFold applies the ContainsFold predicate on the "manufacturer" field.

func ManufacturerEQ

func ManufacturerEQ(v string) predicate.Entity

ManufacturerEQ applies the EQ predicate on the "manufacturer" field.

func ManufacturerEqualFold

func ManufacturerEqualFold(v string) predicate.Entity

ManufacturerEqualFold applies the EqualFold predicate on the "manufacturer" field.

func ManufacturerGT

func ManufacturerGT(v string) predicate.Entity

ManufacturerGT applies the GT predicate on the "manufacturer" field.

func ManufacturerGTE

func ManufacturerGTE(v string) predicate.Entity

ManufacturerGTE applies the GTE predicate on the "manufacturer" field.

func ManufacturerHasPrefix

func ManufacturerHasPrefix(v string) predicate.Entity

ManufacturerHasPrefix applies the HasPrefix predicate on the "manufacturer" field.

func ManufacturerHasSuffix

func ManufacturerHasSuffix(v string) predicate.Entity

ManufacturerHasSuffix applies the HasSuffix predicate on the "manufacturer" field.

func ManufacturerIn

func ManufacturerIn(vs ...string) predicate.Entity

ManufacturerIn applies the In predicate on the "manufacturer" field.

func ManufacturerIsNil

func ManufacturerIsNil() predicate.Entity

ManufacturerIsNil applies the IsNil predicate on the "manufacturer" field.

func ManufacturerLT

func ManufacturerLT(v string) predicate.Entity

ManufacturerLT applies the LT predicate on the "manufacturer" field.

func ManufacturerLTE

func ManufacturerLTE(v string) predicate.Entity

ManufacturerLTE applies the LTE predicate on the "manufacturer" field.

func ManufacturerNEQ

func ManufacturerNEQ(v string) predicate.Entity

ManufacturerNEQ applies the NEQ predicate on the "manufacturer" field.

func ManufacturerNotIn

func ManufacturerNotIn(vs ...string) predicate.Entity

ManufacturerNotIn applies the NotIn predicate on the "manufacturer" field.

func ManufacturerNotNil

func ManufacturerNotNil() predicate.Entity

ManufacturerNotNil applies the NotNil predicate on the "manufacturer" field.

func ModelNumber

func ModelNumber(v string) predicate.Entity

ModelNumber applies equality check predicate on the "model_number" field. It's identical to ModelNumberEQ.

func ModelNumberContains

func ModelNumberContains(v string) predicate.Entity

ModelNumberContains applies the Contains predicate on the "model_number" field.

func ModelNumberContainsFold

func ModelNumberContainsFold(v string) predicate.Entity

ModelNumberContainsFold applies the ContainsFold predicate on the "model_number" field.

func ModelNumberEQ

func ModelNumberEQ(v string) predicate.Entity

ModelNumberEQ applies the EQ predicate on the "model_number" field.

func ModelNumberEqualFold

func ModelNumberEqualFold(v string) predicate.Entity

ModelNumberEqualFold applies the EqualFold predicate on the "model_number" field.

func ModelNumberGT

func ModelNumberGT(v string) predicate.Entity

ModelNumberGT applies the GT predicate on the "model_number" field.

func ModelNumberGTE

func ModelNumberGTE(v string) predicate.Entity

ModelNumberGTE applies the GTE predicate on the "model_number" field.

func ModelNumberHasPrefix

func ModelNumberHasPrefix(v string) predicate.Entity

ModelNumberHasPrefix applies the HasPrefix predicate on the "model_number" field.

func ModelNumberHasSuffix

func ModelNumberHasSuffix(v string) predicate.Entity

ModelNumberHasSuffix applies the HasSuffix predicate on the "model_number" field.

func ModelNumberIn

func ModelNumberIn(vs ...string) predicate.Entity

ModelNumberIn applies the In predicate on the "model_number" field.

func ModelNumberIsNil

func ModelNumberIsNil() predicate.Entity

ModelNumberIsNil applies the IsNil predicate on the "model_number" field.

func ModelNumberLT

func ModelNumberLT(v string) predicate.Entity

ModelNumberLT applies the LT predicate on the "model_number" field.

func ModelNumberLTE

func ModelNumberLTE(v string) predicate.Entity

ModelNumberLTE applies the LTE predicate on the "model_number" field.

func ModelNumberNEQ

func ModelNumberNEQ(v string) predicate.Entity

ModelNumberNEQ applies the NEQ predicate on the "model_number" field.

func ModelNumberNotIn

func ModelNumberNotIn(vs ...string) predicate.Entity

ModelNumberNotIn applies the NotIn predicate on the "model_number" field.

func ModelNumberNotNil

func ModelNumberNotNil() predicate.Entity

ModelNumberNotNil applies the NotNil predicate on the "model_number" field.

func Name

func Name(v string) predicate.Entity

Name applies equality check predicate on the "name" field. It's identical to NameEQ.

func NameContains

func NameContains(v string) predicate.Entity

NameContains applies the Contains predicate on the "name" field.

func NameContainsFold

func NameContainsFold(v string) predicate.Entity

NameContainsFold applies the ContainsFold predicate on the "name" field.

func NameEQ

func NameEQ(v string) predicate.Entity

NameEQ applies the EQ predicate on the "name" field.

func NameEqualFold

func NameEqualFold(v string) predicate.Entity

NameEqualFold applies the EqualFold predicate on the "name" field.

func NameGT

func NameGT(v string) predicate.Entity

NameGT applies the GT predicate on the "name" field.

func NameGTE

func NameGTE(v string) predicate.Entity

NameGTE applies the GTE predicate on the "name" field.

func NameHasPrefix

func NameHasPrefix(v string) predicate.Entity

NameHasPrefix applies the HasPrefix predicate on the "name" field.

func NameHasSuffix

func NameHasSuffix(v string) predicate.Entity

NameHasSuffix applies the HasSuffix predicate on the "name" field.

func NameIn

func NameIn(vs ...string) predicate.Entity

NameIn applies the In predicate on the "name" field.

func NameLT

func NameLT(v string) predicate.Entity

NameLT applies the LT predicate on the "name" field.

func NameLTE

func NameLTE(v string) predicate.Entity

NameLTE applies the LTE predicate on the "name" field.

func NameNEQ

func NameNEQ(v string) predicate.Entity

NameNEQ applies the NEQ predicate on the "name" field.

func NameNotIn

func NameNotIn(vs ...string) predicate.Entity

NameNotIn applies the NotIn predicate on the "name" field.

func Not

Not applies the not operator on the given predicate.

func Notes

func Notes(v string) predicate.Entity

Notes applies equality check predicate on the "notes" field. It's identical to NotesEQ.

func NotesContains

func NotesContains(v string) predicate.Entity

NotesContains applies the Contains predicate on the "notes" field.

func NotesContainsFold

func NotesContainsFold(v string) predicate.Entity

NotesContainsFold applies the ContainsFold predicate on the "notes" field.

func NotesEQ

func NotesEQ(v string) predicate.Entity

NotesEQ applies the EQ predicate on the "notes" field.

func NotesEqualFold

func NotesEqualFold(v string) predicate.Entity

NotesEqualFold applies the EqualFold predicate on the "notes" field.

func NotesGT

func NotesGT(v string) predicate.Entity

NotesGT applies the GT predicate on the "notes" field.

func NotesGTE

func NotesGTE(v string) predicate.Entity

NotesGTE applies the GTE predicate on the "notes" field.

func NotesHasPrefix

func NotesHasPrefix(v string) predicate.Entity

NotesHasPrefix applies the HasPrefix predicate on the "notes" field.

func NotesHasSuffix

func NotesHasSuffix(v string) predicate.Entity

NotesHasSuffix applies the HasSuffix predicate on the "notes" field.

func NotesIn

func NotesIn(vs ...string) predicate.Entity

NotesIn applies the In predicate on the "notes" field.

func NotesIsNil

func NotesIsNil() predicate.Entity

NotesIsNil applies the IsNil predicate on the "notes" field.

func NotesLT

func NotesLT(v string) predicate.Entity

NotesLT applies the LT predicate on the "notes" field.

func NotesLTE

func NotesLTE(v string) predicate.Entity

NotesLTE applies the LTE predicate on the "notes" field.

func NotesNEQ

func NotesNEQ(v string) predicate.Entity

NotesNEQ applies the NEQ predicate on the "notes" field.

func NotesNotIn

func NotesNotIn(vs ...string) predicate.Entity

NotesNotIn applies the NotIn predicate on the "notes" field.

func NotesNotNil

func NotesNotNil() predicate.Entity

NotesNotNil applies the NotNil predicate on the "notes" field.

func Or

func Or(predicates ...predicate.Entity) predicate.Entity

Or groups predicates with the OR operator between them.

func PurchaseDate

func PurchaseDate(v time.Time) predicate.Entity

PurchaseDate applies equality check predicate on the "purchase_date" field. It's identical to PurchaseDateEQ.

func PurchaseDateEQ

func PurchaseDateEQ(v time.Time) predicate.Entity

PurchaseDateEQ applies the EQ predicate on the "purchase_date" field.

func PurchaseDateGT

func PurchaseDateGT(v time.Time) predicate.Entity

PurchaseDateGT applies the GT predicate on the "purchase_date" field.

func PurchaseDateGTE

func PurchaseDateGTE(v time.Time) predicate.Entity

PurchaseDateGTE applies the GTE predicate on the "purchase_date" field.

func PurchaseDateIn

func PurchaseDateIn(vs ...time.Time) predicate.Entity

PurchaseDateIn applies the In predicate on the "purchase_date" field.

func PurchaseDateIsNil

func PurchaseDateIsNil() predicate.Entity

PurchaseDateIsNil applies the IsNil predicate on the "purchase_date" field.

func PurchaseDateLT

func PurchaseDateLT(v time.Time) predicate.Entity

PurchaseDateLT applies the LT predicate on the "purchase_date" field.

func PurchaseDateLTE

func PurchaseDateLTE(v time.Time) predicate.Entity

PurchaseDateLTE applies the LTE predicate on the "purchase_date" field.

func PurchaseDateNEQ

func PurchaseDateNEQ(v time.Time) predicate.Entity

PurchaseDateNEQ applies the NEQ predicate on the "purchase_date" field.

func PurchaseDateNotIn

func PurchaseDateNotIn(vs ...time.Time) predicate.Entity

PurchaseDateNotIn applies the NotIn predicate on the "purchase_date" field.

func PurchaseDateNotNil

func PurchaseDateNotNil() predicate.Entity

PurchaseDateNotNil applies the NotNil predicate on the "purchase_date" field.

func PurchaseFrom

func PurchaseFrom(v string) predicate.Entity

PurchaseFrom applies equality check predicate on the "purchase_from" field. It's identical to PurchaseFromEQ.

func PurchaseFromContains

func PurchaseFromContains(v string) predicate.Entity

PurchaseFromContains applies the Contains predicate on the "purchase_from" field.

func PurchaseFromContainsFold

func PurchaseFromContainsFold(v string) predicate.Entity

PurchaseFromContainsFold applies the ContainsFold predicate on the "purchase_from" field.

func PurchaseFromEQ

func PurchaseFromEQ(v string) predicate.Entity

PurchaseFromEQ applies the EQ predicate on the "purchase_from" field.

func PurchaseFromEqualFold

func PurchaseFromEqualFold(v string) predicate.Entity

PurchaseFromEqualFold applies the EqualFold predicate on the "purchase_from" field.

func PurchaseFromGT

func PurchaseFromGT(v string) predicate.Entity

PurchaseFromGT applies the GT predicate on the "purchase_from" field.

func PurchaseFromGTE

func PurchaseFromGTE(v string) predicate.Entity

PurchaseFromGTE applies the GTE predicate on the "purchase_from" field.

func PurchaseFromHasPrefix

func PurchaseFromHasPrefix(v string) predicate.Entity

PurchaseFromHasPrefix applies the HasPrefix predicate on the "purchase_from" field.

func PurchaseFromHasSuffix

func PurchaseFromHasSuffix(v string) predicate.Entity

PurchaseFromHasSuffix applies the HasSuffix predicate on the "purchase_from" field.

func PurchaseFromIn

func PurchaseFromIn(vs ...string) predicate.Entity

PurchaseFromIn applies the In predicate on the "purchase_from" field.

func PurchaseFromIsNil

func PurchaseFromIsNil() predicate.Entity

PurchaseFromIsNil applies the IsNil predicate on the "purchase_from" field.

func PurchaseFromLT

func PurchaseFromLT(v string) predicate.Entity

PurchaseFromLT applies the LT predicate on the "purchase_from" field.

func PurchaseFromLTE

func PurchaseFromLTE(v string) predicate.Entity

PurchaseFromLTE applies the LTE predicate on the "purchase_from" field.

func PurchaseFromNEQ

func PurchaseFromNEQ(v string) predicate.Entity

PurchaseFromNEQ applies the NEQ predicate on the "purchase_from" field.

func PurchaseFromNotIn

func PurchaseFromNotIn(vs ...string) predicate.Entity

PurchaseFromNotIn applies the NotIn predicate on the "purchase_from" field.

func PurchaseFromNotNil

func PurchaseFromNotNil() predicate.Entity

PurchaseFromNotNil applies the NotNil predicate on the "purchase_from" field.

func PurchasePrice

func PurchasePrice(v float64) predicate.Entity

PurchasePrice applies equality check predicate on the "purchase_price" field. It's identical to PurchasePriceEQ.

func PurchasePriceEQ

func PurchasePriceEQ(v float64) predicate.Entity

PurchasePriceEQ applies the EQ predicate on the "purchase_price" field.

func PurchasePriceGT

func PurchasePriceGT(v float64) predicate.Entity

PurchasePriceGT applies the GT predicate on the "purchase_price" field.

func PurchasePriceGTE

func PurchasePriceGTE(v float64) predicate.Entity

PurchasePriceGTE applies the GTE predicate on the "purchase_price" field.

func PurchasePriceIn

func PurchasePriceIn(vs ...float64) predicate.Entity

PurchasePriceIn applies the In predicate on the "purchase_price" field.

func PurchasePriceLT

func PurchasePriceLT(v float64) predicate.Entity

PurchasePriceLT applies the LT predicate on the "purchase_price" field.

func PurchasePriceLTE

func PurchasePriceLTE(v float64) predicate.Entity

PurchasePriceLTE applies the LTE predicate on the "purchase_price" field.

func PurchasePriceNEQ

func PurchasePriceNEQ(v float64) predicate.Entity

PurchasePriceNEQ applies the NEQ predicate on the "purchase_price" field.

func PurchasePriceNotIn

func PurchasePriceNotIn(vs ...float64) predicate.Entity

PurchasePriceNotIn applies the NotIn predicate on the "purchase_price" field.

func Quantity

func Quantity(v float64) predicate.Entity

Quantity applies equality check predicate on the "quantity" field. It's identical to QuantityEQ.

func QuantityEQ

func QuantityEQ(v float64) predicate.Entity

QuantityEQ applies the EQ predicate on the "quantity" field.

func QuantityGT

func QuantityGT(v float64) predicate.Entity

QuantityGT applies the GT predicate on the "quantity" field.

func QuantityGTE

func QuantityGTE(v float64) predicate.Entity

QuantityGTE applies the GTE predicate on the "quantity" field.

func QuantityIn

func QuantityIn(vs ...float64) predicate.Entity

QuantityIn applies the In predicate on the "quantity" field.

func QuantityLT

func QuantityLT(v float64) predicate.Entity

QuantityLT applies the LT predicate on the "quantity" field.

func QuantityLTE

func QuantityLTE(v float64) predicate.Entity

QuantityLTE applies the LTE predicate on the "quantity" field.

func QuantityNEQ

func QuantityNEQ(v float64) predicate.Entity

QuantityNEQ applies the NEQ predicate on the "quantity" field.

func QuantityNotIn

func QuantityNotIn(vs ...float64) predicate.Entity

QuantityNotIn applies the NotIn predicate on the "quantity" field.

func SerialNumber

func SerialNumber(v string) predicate.Entity

SerialNumber applies equality check predicate on the "serial_number" field. It's identical to SerialNumberEQ.

func SerialNumberContains

func SerialNumberContains(v string) predicate.Entity

SerialNumberContains applies the Contains predicate on the "serial_number" field.

func SerialNumberContainsFold

func SerialNumberContainsFold(v string) predicate.Entity

SerialNumberContainsFold applies the ContainsFold predicate on the "serial_number" field.

func SerialNumberEQ

func SerialNumberEQ(v string) predicate.Entity

SerialNumberEQ applies the EQ predicate on the "serial_number" field.

func SerialNumberEqualFold

func SerialNumberEqualFold(v string) predicate.Entity

SerialNumberEqualFold applies the EqualFold predicate on the "serial_number" field.

func SerialNumberGT

func SerialNumberGT(v string) predicate.Entity

SerialNumberGT applies the GT predicate on the "serial_number" field.

func SerialNumberGTE

func SerialNumberGTE(v string) predicate.Entity

SerialNumberGTE applies the GTE predicate on the "serial_number" field.

func SerialNumberHasPrefix

func SerialNumberHasPrefix(v string) predicate.Entity

SerialNumberHasPrefix applies the HasPrefix predicate on the "serial_number" field.

func SerialNumberHasSuffix

func SerialNumberHasSuffix(v string) predicate.Entity

SerialNumberHasSuffix applies the HasSuffix predicate on the "serial_number" field.

func SerialNumberIn

func SerialNumberIn(vs ...string) predicate.Entity

SerialNumberIn applies the In predicate on the "serial_number" field.

func SerialNumberIsNil

func SerialNumberIsNil() predicate.Entity

SerialNumberIsNil applies the IsNil predicate on the "serial_number" field.

func SerialNumberLT

func SerialNumberLT(v string) predicate.Entity

SerialNumberLT applies the LT predicate on the "serial_number" field.

func SerialNumberLTE

func SerialNumberLTE(v string) predicate.Entity

SerialNumberLTE applies the LTE predicate on the "serial_number" field.

func SerialNumberNEQ

func SerialNumberNEQ(v string) predicate.Entity

SerialNumberNEQ applies the NEQ predicate on the "serial_number" field.

func SerialNumberNotIn

func SerialNumberNotIn(vs ...string) predicate.Entity

SerialNumberNotIn applies the NotIn predicate on the "serial_number" field.

func SerialNumberNotNil

func SerialNumberNotNil() predicate.Entity

SerialNumberNotNil applies the NotNil predicate on the "serial_number" field.

func SoldDate

func SoldDate(v time.Time) predicate.Entity

SoldDate applies equality check predicate on the "sold_date" field. It's identical to SoldDateEQ.

func SoldDateEQ

func SoldDateEQ(v time.Time) predicate.Entity

SoldDateEQ applies the EQ predicate on the "sold_date" field.

func SoldDateGT

func SoldDateGT(v time.Time) predicate.Entity

SoldDateGT applies the GT predicate on the "sold_date" field.

func SoldDateGTE

func SoldDateGTE(v time.Time) predicate.Entity

SoldDateGTE applies the GTE predicate on the "sold_date" field.

func SoldDateIn

func SoldDateIn(vs ...time.Time) predicate.Entity

SoldDateIn applies the In predicate on the "sold_date" field.

func SoldDateIsNil

func SoldDateIsNil() predicate.Entity

SoldDateIsNil applies the IsNil predicate on the "sold_date" field.

func SoldDateLT

func SoldDateLT(v time.Time) predicate.Entity

SoldDateLT applies the LT predicate on the "sold_date" field.

func SoldDateLTE

func SoldDateLTE(v time.Time) predicate.Entity

SoldDateLTE applies the LTE predicate on the "sold_date" field.

func SoldDateNEQ

func SoldDateNEQ(v time.Time) predicate.Entity

SoldDateNEQ applies the NEQ predicate on the "sold_date" field.

func SoldDateNotIn

func SoldDateNotIn(vs ...time.Time) predicate.Entity

SoldDateNotIn applies the NotIn predicate on the "sold_date" field.

func SoldDateNotNil

func SoldDateNotNil() predicate.Entity

SoldDateNotNil applies the NotNil predicate on the "sold_date" field.

func SoldNotes

func SoldNotes(v string) predicate.Entity

SoldNotes applies equality check predicate on the "sold_notes" field. It's identical to SoldNotesEQ.

func SoldNotesContains

func SoldNotesContains(v string) predicate.Entity

SoldNotesContains applies the Contains predicate on the "sold_notes" field.

func SoldNotesContainsFold

func SoldNotesContainsFold(v string) predicate.Entity

SoldNotesContainsFold applies the ContainsFold predicate on the "sold_notes" field.

func SoldNotesEQ

func SoldNotesEQ(v string) predicate.Entity

SoldNotesEQ applies the EQ predicate on the "sold_notes" field.

func SoldNotesEqualFold

func SoldNotesEqualFold(v string) predicate.Entity

SoldNotesEqualFold applies the EqualFold predicate on the "sold_notes" field.

func SoldNotesGT

func SoldNotesGT(v string) predicate.Entity

SoldNotesGT applies the GT predicate on the "sold_notes" field.

func SoldNotesGTE

func SoldNotesGTE(v string) predicate.Entity

SoldNotesGTE applies the GTE predicate on the "sold_notes" field.

func SoldNotesHasPrefix

func SoldNotesHasPrefix(v string) predicate.Entity

SoldNotesHasPrefix applies the HasPrefix predicate on the "sold_notes" field.

func SoldNotesHasSuffix

func SoldNotesHasSuffix(v string) predicate.Entity

SoldNotesHasSuffix applies the HasSuffix predicate on the "sold_notes" field.

func SoldNotesIn

func SoldNotesIn(vs ...string) predicate.Entity

SoldNotesIn applies the In predicate on the "sold_notes" field.

func SoldNotesIsNil

func SoldNotesIsNil() predicate.Entity

SoldNotesIsNil applies the IsNil predicate on the "sold_notes" field.

func SoldNotesLT

func SoldNotesLT(v string) predicate.Entity

SoldNotesLT applies the LT predicate on the "sold_notes" field.

func SoldNotesLTE

func SoldNotesLTE(v string) predicate.Entity

SoldNotesLTE applies the LTE predicate on the "sold_notes" field.

func SoldNotesNEQ

func SoldNotesNEQ(v string) predicate.Entity

SoldNotesNEQ applies the NEQ predicate on the "sold_notes" field.

func SoldNotesNotIn

func SoldNotesNotIn(vs ...string) predicate.Entity

SoldNotesNotIn applies the NotIn predicate on the "sold_notes" field.

func SoldNotesNotNil

func SoldNotesNotNil() predicate.Entity

SoldNotesNotNil applies the NotNil predicate on the "sold_notes" field.

func SoldPrice

func SoldPrice(v float64) predicate.Entity

SoldPrice applies equality check predicate on the "sold_price" field. It's identical to SoldPriceEQ.

func SoldPriceEQ

func SoldPriceEQ(v float64) predicate.Entity

SoldPriceEQ applies the EQ predicate on the "sold_price" field.

func SoldPriceGT

func SoldPriceGT(v float64) predicate.Entity

SoldPriceGT applies the GT predicate on the "sold_price" field.

func SoldPriceGTE

func SoldPriceGTE(v float64) predicate.Entity

SoldPriceGTE applies the GTE predicate on the "sold_price" field.

func SoldPriceIn

func SoldPriceIn(vs ...float64) predicate.Entity

SoldPriceIn applies the In predicate on the "sold_price" field.

func SoldPriceLT

func SoldPriceLT(v float64) predicate.Entity

SoldPriceLT applies the LT predicate on the "sold_price" field.

func SoldPriceLTE

func SoldPriceLTE(v float64) predicate.Entity

SoldPriceLTE applies the LTE predicate on the "sold_price" field.

func SoldPriceNEQ

func SoldPriceNEQ(v float64) predicate.Entity

SoldPriceNEQ applies the NEQ predicate on the "sold_price" field.

func SoldPriceNotIn

func SoldPriceNotIn(vs ...float64) predicate.Entity

SoldPriceNotIn applies the NotIn predicate on the "sold_price" field.

func SoldTo

func SoldTo(v string) predicate.Entity

SoldTo applies equality check predicate on the "sold_to" field. It's identical to SoldToEQ.

func SoldToContains

func SoldToContains(v string) predicate.Entity

SoldToContains applies the Contains predicate on the "sold_to" field.

func SoldToContainsFold

func SoldToContainsFold(v string) predicate.Entity

SoldToContainsFold applies the ContainsFold predicate on the "sold_to" field.

func SoldToEQ

func SoldToEQ(v string) predicate.Entity

SoldToEQ applies the EQ predicate on the "sold_to" field.

func SoldToEqualFold

func SoldToEqualFold(v string) predicate.Entity

SoldToEqualFold applies the EqualFold predicate on the "sold_to" field.

func SoldToGT

func SoldToGT(v string) predicate.Entity

SoldToGT applies the GT predicate on the "sold_to" field.

func SoldToGTE

func SoldToGTE(v string) predicate.Entity

SoldToGTE applies the GTE predicate on the "sold_to" field.

func SoldToHasPrefix

func SoldToHasPrefix(v string) predicate.Entity

SoldToHasPrefix applies the HasPrefix predicate on the "sold_to" field.

func SoldToHasSuffix

func SoldToHasSuffix(v string) predicate.Entity

SoldToHasSuffix applies the HasSuffix predicate on the "sold_to" field.

func SoldToIn

func SoldToIn(vs ...string) predicate.Entity

SoldToIn applies the In predicate on the "sold_to" field.

func SoldToIsNil

func SoldToIsNil() predicate.Entity

SoldToIsNil applies the IsNil predicate on the "sold_to" field.

func SoldToLT

func SoldToLT(v string) predicate.Entity

SoldToLT applies the LT predicate on the "sold_to" field.

func SoldToLTE

func SoldToLTE(v string) predicate.Entity

SoldToLTE applies the LTE predicate on the "sold_to" field.

func SoldToNEQ

func SoldToNEQ(v string) predicate.Entity

SoldToNEQ applies the NEQ predicate on the "sold_to" field.

func SoldToNotIn

func SoldToNotIn(vs ...string) predicate.Entity

SoldToNotIn applies the NotIn predicate on the "sold_to" field.

func SoldToNotNil

func SoldToNotNil() predicate.Entity

SoldToNotNil applies the NotNil predicate on the "sold_to" field.

func SyncChildEntityLocations

func SyncChildEntityLocations(v bool) predicate.Entity

SyncChildEntityLocations applies equality check predicate on the "sync_child_entity_locations" field. It's identical to SyncChildEntityLocationsEQ.

func SyncChildEntityLocationsEQ

func SyncChildEntityLocationsEQ(v bool) predicate.Entity

SyncChildEntityLocationsEQ applies the EQ predicate on the "sync_child_entity_locations" field.

func SyncChildEntityLocationsNEQ

func SyncChildEntityLocationsNEQ(v bool) predicate.Entity

SyncChildEntityLocationsNEQ applies the NEQ predicate on the "sync_child_entity_locations" field.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.Entity

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.Entity

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.Entity

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.Entity

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.Entity

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.Entity

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.Entity

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.Entity

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.Entity

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

func WarrantyDetails

func WarrantyDetails(v string) predicate.Entity

WarrantyDetails applies equality check predicate on the "warranty_details" field. It's identical to WarrantyDetailsEQ.

func WarrantyDetailsContains

func WarrantyDetailsContains(v string) predicate.Entity

WarrantyDetailsContains applies the Contains predicate on the "warranty_details" field.

func WarrantyDetailsContainsFold

func WarrantyDetailsContainsFold(v string) predicate.Entity

WarrantyDetailsContainsFold applies the ContainsFold predicate on the "warranty_details" field.

func WarrantyDetailsEQ

func WarrantyDetailsEQ(v string) predicate.Entity

WarrantyDetailsEQ applies the EQ predicate on the "warranty_details" field.

func WarrantyDetailsEqualFold

func WarrantyDetailsEqualFold(v string) predicate.Entity

WarrantyDetailsEqualFold applies the EqualFold predicate on the "warranty_details" field.

func WarrantyDetailsGT

func WarrantyDetailsGT(v string) predicate.Entity

WarrantyDetailsGT applies the GT predicate on the "warranty_details" field.

func WarrantyDetailsGTE

func WarrantyDetailsGTE(v string) predicate.Entity

WarrantyDetailsGTE applies the GTE predicate on the "warranty_details" field.

func WarrantyDetailsHasPrefix

func WarrantyDetailsHasPrefix(v string) predicate.Entity

WarrantyDetailsHasPrefix applies the HasPrefix predicate on the "warranty_details" field.

func WarrantyDetailsHasSuffix

func WarrantyDetailsHasSuffix(v string) predicate.Entity

WarrantyDetailsHasSuffix applies the HasSuffix predicate on the "warranty_details" field.

func WarrantyDetailsIn

func WarrantyDetailsIn(vs ...string) predicate.Entity

WarrantyDetailsIn applies the In predicate on the "warranty_details" field.

func WarrantyDetailsIsNil

func WarrantyDetailsIsNil() predicate.Entity

WarrantyDetailsIsNil applies the IsNil predicate on the "warranty_details" field.

func WarrantyDetailsLT

func WarrantyDetailsLT(v string) predicate.Entity

WarrantyDetailsLT applies the LT predicate on the "warranty_details" field.

func WarrantyDetailsLTE

func WarrantyDetailsLTE(v string) predicate.Entity

WarrantyDetailsLTE applies the LTE predicate on the "warranty_details" field.

func WarrantyDetailsNEQ

func WarrantyDetailsNEQ(v string) predicate.Entity

WarrantyDetailsNEQ applies the NEQ predicate on the "warranty_details" field.

func WarrantyDetailsNotIn

func WarrantyDetailsNotIn(vs ...string) predicate.Entity

WarrantyDetailsNotIn applies the NotIn predicate on the "warranty_details" field.

func WarrantyDetailsNotNil

func WarrantyDetailsNotNil() predicate.Entity

WarrantyDetailsNotNil applies the NotNil predicate on the "warranty_details" field.

func WarrantyExpires

func WarrantyExpires(v time.Time) predicate.Entity

WarrantyExpires applies equality check predicate on the "warranty_expires" field. It's identical to WarrantyExpiresEQ.

func WarrantyExpiresEQ

func WarrantyExpiresEQ(v time.Time) predicate.Entity

WarrantyExpiresEQ applies the EQ predicate on the "warranty_expires" field.

func WarrantyExpiresGT

func WarrantyExpiresGT(v time.Time) predicate.Entity

WarrantyExpiresGT applies the GT predicate on the "warranty_expires" field.

func WarrantyExpiresGTE

func WarrantyExpiresGTE(v time.Time) predicate.Entity

WarrantyExpiresGTE applies the GTE predicate on the "warranty_expires" field.

func WarrantyExpiresIn

func WarrantyExpiresIn(vs ...time.Time) predicate.Entity

WarrantyExpiresIn applies the In predicate on the "warranty_expires" field.

func WarrantyExpiresIsNil

func WarrantyExpiresIsNil() predicate.Entity

WarrantyExpiresIsNil applies the IsNil predicate on the "warranty_expires" field.

func WarrantyExpiresLT

func WarrantyExpiresLT(v time.Time) predicate.Entity

WarrantyExpiresLT applies the LT predicate on the "warranty_expires" field.

func WarrantyExpiresLTE

func WarrantyExpiresLTE(v time.Time) predicate.Entity

WarrantyExpiresLTE applies the LTE predicate on the "warranty_expires" field.

func WarrantyExpiresNEQ

func WarrantyExpiresNEQ(v time.Time) predicate.Entity

WarrantyExpiresNEQ applies the NEQ predicate on the "warranty_expires" field.

func WarrantyExpiresNotIn

func WarrantyExpiresNotIn(vs ...time.Time) predicate.Entity

WarrantyExpiresNotIn applies the NotIn predicate on the "warranty_expires" field.

func WarrantyExpiresNotNil

func WarrantyExpiresNotNil() predicate.Entity

WarrantyExpiresNotNil applies the NotNil predicate on the "warranty_expires" field.

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Entity queries.

func ByArchived

func ByArchived(opts ...sql.OrderTermOption) OrderOption

ByArchived orders the results by the archived field.

func ByAssetID

func ByAssetID(opts ...sql.OrderTermOption) OrderOption

ByAssetID orders the results by the asset_id field.

func ByAttachments

func ByAttachments(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByAttachments orders the results by attachments terms.

func ByAttachmentsCount

func ByAttachmentsCount(opts ...sql.OrderTermOption) OrderOption

ByAttachmentsCount orders the results by attachments count.

func ByChildren

func ByChildren(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByChildren orders the results by children terms.

func ByChildrenCount

func ByChildrenCount(opts ...sql.OrderTermOption) OrderOption

ByChildrenCount orders the results by children count.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByDescription

func ByDescription(opts ...sql.OrderTermOption) OrderOption

ByDescription orders the results by the description field.

func ByEntityTypeField

func ByEntityTypeField(field string, opts ...sql.OrderTermOption) OrderOption

ByEntityTypeField orders the results by entity_type field.

func ByFields

func ByFields(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByFields orders the results by fields terms.

func ByFieldsCount

func ByFieldsCount(opts ...sql.OrderTermOption) OrderOption

ByFieldsCount orders the results by fields count.

func ByGroupField

func ByGroupField(field string, opts ...sql.OrderTermOption) OrderOption

ByGroupField orders the results by group field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByImportRef

func ByImportRef(opts ...sql.OrderTermOption) OrderOption

ByImportRef orders the results by the import_ref field.

func ByInsured

func ByInsured(opts ...sql.OrderTermOption) OrderOption

ByInsured orders the results by the insured field.

func ByLifetimeWarranty

func ByLifetimeWarranty(opts ...sql.OrderTermOption) OrderOption

ByLifetimeWarranty orders the results by the lifetime_warranty field.

func ByMaintenanceEntries

func ByMaintenanceEntries(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByMaintenanceEntries orders the results by maintenance_entries terms.

func ByMaintenanceEntriesCount

func ByMaintenanceEntriesCount(opts ...sql.OrderTermOption) OrderOption

ByMaintenanceEntriesCount orders the results by maintenance_entries count.

func ByManufacturer

func ByManufacturer(opts ...sql.OrderTermOption) OrderOption

ByManufacturer orders the results by the manufacturer field.

func ByModelNumber

func ByModelNumber(opts ...sql.OrderTermOption) OrderOption

ByModelNumber orders the results by the model_number field.

func ByName

func ByName(opts ...sql.OrderTermOption) OrderOption

ByName orders the results by the name field.

func ByNotes

func ByNotes(opts ...sql.OrderTermOption) OrderOption

ByNotes orders the results by the notes field.

func ByParentField

func ByParentField(field string, opts ...sql.OrderTermOption) OrderOption

ByParentField orders the results by parent field.

func ByPurchaseDate

func ByPurchaseDate(opts ...sql.OrderTermOption) OrderOption

ByPurchaseDate orders the results by the purchase_date field.

func ByPurchaseFrom

func ByPurchaseFrom(opts ...sql.OrderTermOption) OrderOption

ByPurchaseFrom orders the results by the purchase_from field.

func ByPurchasePrice

func ByPurchasePrice(opts ...sql.OrderTermOption) OrderOption

ByPurchasePrice orders the results by the purchase_price field.

func ByQuantity

func ByQuantity(opts ...sql.OrderTermOption) OrderOption

ByQuantity orders the results by the quantity field.

func BySerialNumber

func BySerialNumber(opts ...sql.OrderTermOption) OrderOption

BySerialNumber orders the results by the serial_number field.

func BySoldDate

func BySoldDate(opts ...sql.OrderTermOption) OrderOption

BySoldDate orders the results by the sold_date field.

func BySoldNotes

func BySoldNotes(opts ...sql.OrderTermOption) OrderOption

BySoldNotes orders the results by the sold_notes field.

func BySoldPrice

func BySoldPrice(opts ...sql.OrderTermOption) OrderOption

BySoldPrice orders the results by the sold_price field.

func BySoldTo

func BySoldTo(opts ...sql.OrderTermOption) OrderOption

BySoldTo orders the results by the sold_to field.

func BySyncChildEntityLocations

func BySyncChildEntityLocations(opts ...sql.OrderTermOption) OrderOption

BySyncChildEntityLocations orders the results by the sync_child_entity_locations field.

func ByTag

func ByTag(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByTag orders the results by tag terms.

func ByTagCount

func ByTagCount(opts ...sql.OrderTermOption) OrderOption

ByTagCount orders the results by tag count.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

func ByWarrantyDetails

func ByWarrantyDetails(opts ...sql.OrderTermOption) OrderOption

ByWarrantyDetails orders the results by the warranty_details field.

func ByWarrantyExpires

func ByWarrantyExpires(opts ...sql.OrderTermOption) OrderOption

ByWarrantyExpires orders the results by the warranty_expires field.

Jump to