user

package
v0.0.0-...-e8af2e3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 16, 2026 License: AGPL-3.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the user type in the database.
	Label = "user"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// FieldName holds the string denoting the name field in the database.
	FieldName = "name"
	// FieldEmail holds the string denoting the email field in the database.
	FieldEmail = "email"
	// FieldPassword holds the string denoting the password field in the database.
	FieldPassword = "password"
	// FieldIsSuperuser holds the string denoting the is_superuser field in the database.
	FieldIsSuperuser = "is_superuser"
	// FieldSuperuser holds the string denoting the superuser field in the database.
	FieldSuperuser = "superuser"
	// FieldActivatedOn holds the string denoting the activated_on field in the database.
	FieldActivatedOn = "activated_on"
	// FieldOidcIssuer holds the string denoting the oidc_issuer field in the database.
	FieldOidcIssuer = "oidc_issuer"
	// FieldOidcSubject holds the string denoting the oidc_subject field in the database.
	FieldOidcSubject = "oidc_subject"
	// FieldDefaultGroupID holds the string denoting the default_group_id field in the database.
	FieldDefaultGroupID = "default_group_id"
	// FieldSettings holds the string denoting the settings field in the database.
	FieldSettings = "settings"
	// EdgeGroups holds the string denoting the groups edge name in mutations.
	EdgeGroups = "groups"
	// EdgeAuthTokens holds the string denoting the auth_tokens edge name in mutations.
	EdgeAuthTokens = "auth_tokens"
	// EdgePasswordResetTokens holds the string denoting the password_reset_tokens edge name in mutations.
	EdgePasswordResetTokens = "password_reset_tokens"
	// EdgeAPIKeys holds the string denoting the api_keys edge name in mutations.
	EdgeAPIKeys = "api_keys"
	// EdgeNotifiers holds the string denoting the notifiers edge name in mutations.
	EdgeNotifiers = "notifiers"
	// EdgeUserGroups holds the string denoting the user_groups edge name in mutations.
	EdgeUserGroups = "user_groups"
	// Table holds the table name of the user in the database.
	Table = "users"
	// GroupsTable is the table that holds the groups relation/edge. The primary key declared below.
	GroupsTable = "user_groups"
	// GroupsInverseTable is the table name for the Group entity.
	// It exists in this package in order to avoid circular dependency with the "group" package.
	GroupsInverseTable = "groups"
	// AuthTokensTable is the table that holds the auth_tokens relation/edge.
	AuthTokensTable = "auth_tokens"
	// AuthTokensInverseTable is the table name for the AuthTokens entity.
	// It exists in this package in order to avoid circular dependency with the "authtokens" package.
	AuthTokensInverseTable = "auth_tokens"
	// AuthTokensColumn is the table column denoting the auth_tokens relation/edge.
	AuthTokensColumn = "user_auth_tokens"
	// PasswordResetTokensTable is the table that holds the password_reset_tokens relation/edge.
	PasswordResetTokensTable = "password_reset_tokens"
	// PasswordResetTokensInverseTable is the table name for the PasswordResetTokens entity.
	// It exists in this package in order to avoid circular dependency with the "passwordresettokens" package.
	PasswordResetTokensInverseTable = "password_reset_tokens"
	// PasswordResetTokensColumn is the table column denoting the password_reset_tokens relation/edge.
	PasswordResetTokensColumn = "user_password_reset_tokens"
	// APIKeysTable is the table that holds the api_keys relation/edge.
	APIKeysTable = "api_keys"
	// APIKeysInverseTable is the table name for the APIKey entity.
	// It exists in this package in order to avoid circular dependency with the "apikey" package.
	APIKeysInverseTable = "api_keys"
	// APIKeysColumn is the table column denoting the api_keys relation/edge.
	APIKeysColumn = "user_id"
	// NotifiersTable is the table that holds the notifiers relation/edge.
	NotifiersTable = "notifiers"
	// NotifiersInverseTable is the table name for the Notifier entity.
	// It exists in this package in order to avoid circular dependency with the "notifier" package.
	NotifiersInverseTable = "notifiers"
	// NotifiersColumn is the table column denoting the notifiers relation/edge.
	NotifiersColumn = "user_id"
	// UserGroupsTable is the table that holds the user_groups relation/edge.
	UserGroupsTable = "user_groups"
	// UserGroupsInverseTable is the table name for the UserGroup entity.
	// It exists in this package in order to avoid circular dependency with the "usergroup" package.
	UserGroupsInverseTable = "user_groups"
	// UserGroupsColumn is the table column denoting the user_groups relation/edge.
	UserGroupsColumn = "user_id"
)

Variables

var (
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// NameValidator is a validator for the "name" field. It is called by the builders before save.
	NameValidator func(string) error
	// EmailValidator is a validator for the "email" field. It is called by the builders before save.
	EmailValidator func(string) error
	// PasswordValidator is a validator for the "password" field. It is called by the builders before save.
	PasswordValidator func(string) error
	// DefaultIsSuperuser holds the default value on creation for the "is_superuser" field.
	DefaultIsSuperuser bool
	// DefaultSuperuser holds the default value on creation for the "superuser" field.
	DefaultSuperuser bool
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() uuid.UUID
)

Columns holds all SQL columns for user fields.

var (
	// GroupsPrimaryKey and GroupsColumn2 are the table columns denoting the
	// primary key for the groups relation (M2M).
	GroupsPrimaryKey = []string{"user_id", "group_id"}
)

Functions

func ActivatedOn

func ActivatedOn(v time.Time) predicate.User

ActivatedOn applies equality check predicate on the "activated_on" field. It's identical to ActivatedOnEQ.

func ActivatedOnEQ

func ActivatedOnEQ(v time.Time) predicate.User

ActivatedOnEQ applies the EQ predicate on the "activated_on" field.

func ActivatedOnGT

func ActivatedOnGT(v time.Time) predicate.User

ActivatedOnGT applies the GT predicate on the "activated_on" field.

func ActivatedOnGTE

func ActivatedOnGTE(v time.Time) predicate.User

ActivatedOnGTE applies the GTE predicate on the "activated_on" field.

func ActivatedOnIn

func ActivatedOnIn(vs ...time.Time) predicate.User

ActivatedOnIn applies the In predicate on the "activated_on" field.

func ActivatedOnIsNil

func ActivatedOnIsNil() predicate.User

ActivatedOnIsNil applies the IsNil predicate on the "activated_on" field.

func ActivatedOnLT

func ActivatedOnLT(v time.Time) predicate.User

ActivatedOnLT applies the LT predicate on the "activated_on" field.

func ActivatedOnLTE

func ActivatedOnLTE(v time.Time) predicate.User

ActivatedOnLTE applies the LTE predicate on the "activated_on" field.

func ActivatedOnNEQ

func ActivatedOnNEQ(v time.Time) predicate.User

ActivatedOnNEQ applies the NEQ predicate on the "activated_on" field.

func ActivatedOnNotIn

func ActivatedOnNotIn(vs ...time.Time) predicate.User

ActivatedOnNotIn applies the NotIn predicate on the "activated_on" field.

func ActivatedOnNotNil

func ActivatedOnNotNil() predicate.User

ActivatedOnNotNil applies the NotNil predicate on the "activated_on" field.

func And

func And(predicates ...predicate.User) predicate.User

And groups predicates with the AND operator between them.

func CreatedAt

func CreatedAt(v time.Time) predicate.User

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.User

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.User

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.User

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.User

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.User

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.User

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.User

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.User

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func DefaultGroupID

func DefaultGroupID(v uuid.UUID) predicate.User

DefaultGroupID applies equality check predicate on the "default_group_id" field. It's identical to DefaultGroupIDEQ.

func DefaultGroupIDEQ

func DefaultGroupIDEQ(v uuid.UUID) predicate.User

DefaultGroupIDEQ applies the EQ predicate on the "default_group_id" field.

func DefaultGroupIDGT

func DefaultGroupIDGT(v uuid.UUID) predicate.User

DefaultGroupIDGT applies the GT predicate on the "default_group_id" field.

func DefaultGroupIDGTE

func DefaultGroupIDGTE(v uuid.UUID) predicate.User

DefaultGroupIDGTE applies the GTE predicate on the "default_group_id" field.

func DefaultGroupIDIn

func DefaultGroupIDIn(vs ...uuid.UUID) predicate.User

DefaultGroupIDIn applies the In predicate on the "default_group_id" field.

func DefaultGroupIDIsNil

func DefaultGroupIDIsNil() predicate.User

DefaultGroupIDIsNil applies the IsNil predicate on the "default_group_id" field.

func DefaultGroupIDLT

func DefaultGroupIDLT(v uuid.UUID) predicate.User

DefaultGroupIDLT applies the LT predicate on the "default_group_id" field.

func DefaultGroupIDLTE

func DefaultGroupIDLTE(v uuid.UUID) predicate.User

DefaultGroupIDLTE applies the LTE predicate on the "default_group_id" field.

func DefaultGroupIDNEQ

func DefaultGroupIDNEQ(v uuid.UUID) predicate.User

DefaultGroupIDNEQ applies the NEQ predicate on the "default_group_id" field.

func DefaultGroupIDNotIn

func DefaultGroupIDNotIn(vs ...uuid.UUID) predicate.User

DefaultGroupIDNotIn applies the NotIn predicate on the "default_group_id" field.

func DefaultGroupIDNotNil

func DefaultGroupIDNotNil() predicate.User

DefaultGroupIDNotNil applies the NotNil predicate on the "default_group_id" field.

func Email

func Email(v string) predicate.User

Email applies equality check predicate on the "email" field. It's identical to EmailEQ.

func EmailContains

func EmailContains(v string) predicate.User

EmailContains applies the Contains predicate on the "email" field.

func EmailContainsFold

func EmailContainsFold(v string) predicate.User

EmailContainsFold applies the ContainsFold predicate on the "email" field.

func EmailEQ

func EmailEQ(v string) predicate.User

EmailEQ applies the EQ predicate on the "email" field.

func EmailEqualFold

func EmailEqualFold(v string) predicate.User

EmailEqualFold applies the EqualFold predicate on the "email" field.

func EmailGT

func EmailGT(v string) predicate.User

EmailGT applies the GT predicate on the "email" field.

func EmailGTE

func EmailGTE(v string) predicate.User

EmailGTE applies the GTE predicate on the "email" field.

func EmailHasPrefix

func EmailHasPrefix(v string) predicate.User

EmailHasPrefix applies the HasPrefix predicate on the "email" field.

func EmailHasSuffix

func EmailHasSuffix(v string) predicate.User

EmailHasSuffix applies the HasSuffix predicate on the "email" field.

func EmailIn

func EmailIn(vs ...string) predicate.User

EmailIn applies the In predicate on the "email" field.

func EmailLT

func EmailLT(v string) predicate.User

EmailLT applies the LT predicate on the "email" field.

func EmailLTE

func EmailLTE(v string) predicate.User

EmailLTE applies the LTE predicate on the "email" field.

func EmailNEQ

func EmailNEQ(v string) predicate.User

EmailNEQ applies the NEQ predicate on the "email" field.

func EmailNotIn

func EmailNotIn(vs ...string) predicate.User

EmailNotIn applies the NotIn predicate on the "email" field.

func HasAPIKeys

func HasAPIKeys() predicate.User

HasAPIKeys applies the HasEdge predicate on the "api_keys" edge.

func HasAPIKeysWith

func HasAPIKeysWith(preds ...predicate.APIKey) predicate.User

HasAPIKeysWith applies the HasEdge predicate on the "api_keys" edge with a given conditions (other predicates).

func HasAuthTokens

func HasAuthTokens() predicate.User

HasAuthTokens applies the HasEdge predicate on the "auth_tokens" edge.

func HasAuthTokensWith

func HasAuthTokensWith(preds ...predicate.AuthTokens) predicate.User

HasAuthTokensWith applies the HasEdge predicate on the "auth_tokens" edge with a given conditions (other predicates).

func HasGroups

func HasGroups() predicate.User

HasGroups applies the HasEdge predicate on the "groups" edge.

func HasGroupsWith

func HasGroupsWith(preds ...predicate.Group) predicate.User

HasGroupsWith applies the HasEdge predicate on the "groups" edge with a given conditions (other predicates).

func HasNotifiers

func HasNotifiers() predicate.User

HasNotifiers applies the HasEdge predicate on the "notifiers" edge.

func HasNotifiersWith

func HasNotifiersWith(preds ...predicate.Notifier) predicate.User

HasNotifiersWith applies the HasEdge predicate on the "notifiers" edge with a given conditions (other predicates).

func HasPasswordResetTokens

func HasPasswordResetTokens() predicate.User

HasPasswordResetTokens applies the HasEdge predicate on the "password_reset_tokens" edge.

func HasPasswordResetTokensWith

func HasPasswordResetTokensWith(preds ...predicate.PasswordResetTokens) predicate.User

HasPasswordResetTokensWith applies the HasEdge predicate on the "password_reset_tokens" edge with a given conditions (other predicates).

func HasUserGroups

func HasUserGroups() predicate.User

HasUserGroups applies the HasEdge predicate on the "user_groups" edge.

func HasUserGroupsWith

func HasUserGroupsWith(preds ...predicate.UserGroup) predicate.User

HasUserGroupsWith applies the HasEdge predicate on the "user_groups" edge with a given conditions (other predicates).

func ID

func ID(id uuid.UUID) predicate.User

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id uuid.UUID) predicate.User

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id uuid.UUID) predicate.User

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id uuid.UUID) predicate.User

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uuid.UUID) predicate.User

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id uuid.UUID) predicate.User

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id uuid.UUID) predicate.User

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id uuid.UUID) predicate.User

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uuid.UUID) predicate.User

IDNotIn applies the NotIn predicate on the ID field.

func IsSuperuser

func IsSuperuser(v bool) predicate.User

IsSuperuser applies equality check predicate on the "is_superuser" field. It's identical to IsSuperuserEQ.

func IsSuperuserEQ

func IsSuperuserEQ(v bool) predicate.User

IsSuperuserEQ applies the EQ predicate on the "is_superuser" field.

func IsSuperuserNEQ

func IsSuperuserNEQ(v bool) predicate.User

IsSuperuserNEQ applies the NEQ predicate on the "is_superuser" field.

func Name

func Name(v string) predicate.User

Name applies equality check predicate on the "name" field. It's identical to NameEQ.

func NameContains

func NameContains(v string) predicate.User

NameContains applies the Contains predicate on the "name" field.

func NameContainsFold

func NameContainsFold(v string) predicate.User

NameContainsFold applies the ContainsFold predicate on the "name" field.

func NameEQ

func NameEQ(v string) predicate.User

NameEQ applies the EQ predicate on the "name" field.

func NameEqualFold

func NameEqualFold(v string) predicate.User

NameEqualFold applies the EqualFold predicate on the "name" field.

func NameGT

func NameGT(v string) predicate.User

NameGT applies the GT predicate on the "name" field.

func NameGTE

func NameGTE(v string) predicate.User

NameGTE applies the GTE predicate on the "name" field.

func NameHasPrefix

func NameHasPrefix(v string) predicate.User

NameHasPrefix applies the HasPrefix predicate on the "name" field.

func NameHasSuffix

func NameHasSuffix(v string) predicate.User

NameHasSuffix applies the HasSuffix predicate on the "name" field.

func NameIn

func NameIn(vs ...string) predicate.User

NameIn applies the In predicate on the "name" field.

func NameLT

func NameLT(v string) predicate.User

NameLT applies the LT predicate on the "name" field.

func NameLTE

func NameLTE(v string) predicate.User

NameLTE applies the LTE predicate on the "name" field.

func NameNEQ

func NameNEQ(v string) predicate.User

NameNEQ applies the NEQ predicate on the "name" field.

func NameNotIn

func NameNotIn(vs ...string) predicate.User

NameNotIn applies the NotIn predicate on the "name" field.

func Not

Not applies the not operator on the given predicate.

func OidcIssuer

func OidcIssuer(v string) predicate.User

OidcIssuer applies equality check predicate on the "oidc_issuer" field. It's identical to OidcIssuerEQ.

func OidcIssuerContains

func OidcIssuerContains(v string) predicate.User

OidcIssuerContains applies the Contains predicate on the "oidc_issuer" field.

func OidcIssuerContainsFold

func OidcIssuerContainsFold(v string) predicate.User

OidcIssuerContainsFold applies the ContainsFold predicate on the "oidc_issuer" field.

func OidcIssuerEQ

func OidcIssuerEQ(v string) predicate.User

OidcIssuerEQ applies the EQ predicate on the "oidc_issuer" field.

func OidcIssuerEqualFold

func OidcIssuerEqualFold(v string) predicate.User

OidcIssuerEqualFold applies the EqualFold predicate on the "oidc_issuer" field.

func OidcIssuerGT

func OidcIssuerGT(v string) predicate.User

OidcIssuerGT applies the GT predicate on the "oidc_issuer" field.

func OidcIssuerGTE

func OidcIssuerGTE(v string) predicate.User

OidcIssuerGTE applies the GTE predicate on the "oidc_issuer" field.

func OidcIssuerHasPrefix

func OidcIssuerHasPrefix(v string) predicate.User

OidcIssuerHasPrefix applies the HasPrefix predicate on the "oidc_issuer" field.

func OidcIssuerHasSuffix

func OidcIssuerHasSuffix(v string) predicate.User

OidcIssuerHasSuffix applies the HasSuffix predicate on the "oidc_issuer" field.

func OidcIssuerIn

func OidcIssuerIn(vs ...string) predicate.User

OidcIssuerIn applies the In predicate on the "oidc_issuer" field.

func OidcIssuerIsNil

func OidcIssuerIsNil() predicate.User

OidcIssuerIsNil applies the IsNil predicate on the "oidc_issuer" field.

func OidcIssuerLT

func OidcIssuerLT(v string) predicate.User

OidcIssuerLT applies the LT predicate on the "oidc_issuer" field.

func OidcIssuerLTE

func OidcIssuerLTE(v string) predicate.User

OidcIssuerLTE applies the LTE predicate on the "oidc_issuer" field.

func OidcIssuerNEQ

func OidcIssuerNEQ(v string) predicate.User

OidcIssuerNEQ applies the NEQ predicate on the "oidc_issuer" field.

func OidcIssuerNotIn

func OidcIssuerNotIn(vs ...string) predicate.User

OidcIssuerNotIn applies the NotIn predicate on the "oidc_issuer" field.

func OidcIssuerNotNil

func OidcIssuerNotNil() predicate.User

OidcIssuerNotNil applies the NotNil predicate on the "oidc_issuer" field.

func OidcSubject

func OidcSubject(v string) predicate.User

OidcSubject applies equality check predicate on the "oidc_subject" field. It's identical to OidcSubjectEQ.

func OidcSubjectContains

func OidcSubjectContains(v string) predicate.User

OidcSubjectContains applies the Contains predicate on the "oidc_subject" field.

func OidcSubjectContainsFold

func OidcSubjectContainsFold(v string) predicate.User

OidcSubjectContainsFold applies the ContainsFold predicate on the "oidc_subject" field.

func OidcSubjectEQ

func OidcSubjectEQ(v string) predicate.User

OidcSubjectEQ applies the EQ predicate on the "oidc_subject" field.

func OidcSubjectEqualFold

func OidcSubjectEqualFold(v string) predicate.User

OidcSubjectEqualFold applies the EqualFold predicate on the "oidc_subject" field.

func OidcSubjectGT

func OidcSubjectGT(v string) predicate.User

OidcSubjectGT applies the GT predicate on the "oidc_subject" field.

func OidcSubjectGTE

func OidcSubjectGTE(v string) predicate.User

OidcSubjectGTE applies the GTE predicate on the "oidc_subject" field.

func OidcSubjectHasPrefix

func OidcSubjectHasPrefix(v string) predicate.User

OidcSubjectHasPrefix applies the HasPrefix predicate on the "oidc_subject" field.

func OidcSubjectHasSuffix

func OidcSubjectHasSuffix(v string) predicate.User

OidcSubjectHasSuffix applies the HasSuffix predicate on the "oidc_subject" field.

func OidcSubjectIn

func OidcSubjectIn(vs ...string) predicate.User

OidcSubjectIn applies the In predicate on the "oidc_subject" field.

func OidcSubjectIsNil

func OidcSubjectIsNil() predicate.User

OidcSubjectIsNil applies the IsNil predicate on the "oidc_subject" field.

func OidcSubjectLT

func OidcSubjectLT(v string) predicate.User

OidcSubjectLT applies the LT predicate on the "oidc_subject" field.

func OidcSubjectLTE

func OidcSubjectLTE(v string) predicate.User

OidcSubjectLTE applies the LTE predicate on the "oidc_subject" field.

func OidcSubjectNEQ

func OidcSubjectNEQ(v string) predicate.User

OidcSubjectNEQ applies the NEQ predicate on the "oidc_subject" field.

func OidcSubjectNotIn

func OidcSubjectNotIn(vs ...string) predicate.User

OidcSubjectNotIn applies the NotIn predicate on the "oidc_subject" field.

func OidcSubjectNotNil

func OidcSubjectNotNil() predicate.User

OidcSubjectNotNil applies the NotNil predicate on the "oidc_subject" field.

func Or

func Or(predicates ...predicate.User) predicate.User

Or groups predicates with the OR operator between them.

func Password

func Password(v string) predicate.User

Password applies equality check predicate on the "password" field. It's identical to PasswordEQ.

func PasswordContains

func PasswordContains(v string) predicate.User

PasswordContains applies the Contains predicate on the "password" field.

func PasswordContainsFold

func PasswordContainsFold(v string) predicate.User

PasswordContainsFold applies the ContainsFold predicate on the "password" field.

func PasswordEQ

func PasswordEQ(v string) predicate.User

PasswordEQ applies the EQ predicate on the "password" field.

func PasswordEqualFold

func PasswordEqualFold(v string) predicate.User

PasswordEqualFold applies the EqualFold predicate on the "password" field.

func PasswordGT

func PasswordGT(v string) predicate.User

PasswordGT applies the GT predicate on the "password" field.

func PasswordGTE

func PasswordGTE(v string) predicate.User

PasswordGTE applies the GTE predicate on the "password" field.

func PasswordHasPrefix

func PasswordHasPrefix(v string) predicate.User

PasswordHasPrefix applies the HasPrefix predicate on the "password" field.

func PasswordHasSuffix

func PasswordHasSuffix(v string) predicate.User

PasswordHasSuffix applies the HasSuffix predicate on the "password" field.

func PasswordIn

func PasswordIn(vs ...string) predicate.User

PasswordIn applies the In predicate on the "password" field.

func PasswordIsNil

func PasswordIsNil() predicate.User

PasswordIsNil applies the IsNil predicate on the "password" field.

func PasswordLT

func PasswordLT(v string) predicate.User

PasswordLT applies the LT predicate on the "password" field.

func PasswordLTE

func PasswordLTE(v string) predicate.User

PasswordLTE applies the LTE predicate on the "password" field.

func PasswordNEQ

func PasswordNEQ(v string) predicate.User

PasswordNEQ applies the NEQ predicate on the "password" field.

func PasswordNotIn

func PasswordNotIn(vs ...string) predicate.User

PasswordNotIn applies the NotIn predicate on the "password" field.

func PasswordNotNil

func PasswordNotNil() predicate.User

PasswordNotNil applies the NotNil predicate on the "password" field.

func SettingsIsNil

func SettingsIsNil() predicate.User

SettingsIsNil applies the IsNil predicate on the "settings" field.

func SettingsNotNil

func SettingsNotNil() predicate.User

SettingsNotNil applies the NotNil predicate on the "settings" field.

func Superuser

func Superuser(v bool) predicate.User

Superuser applies equality check predicate on the "superuser" field. It's identical to SuperuserEQ.

func SuperuserEQ

func SuperuserEQ(v bool) predicate.User

SuperuserEQ applies the EQ predicate on the "superuser" field.

func SuperuserNEQ

func SuperuserNEQ(v bool) predicate.User

SuperuserNEQ applies the NEQ predicate on the "superuser" field.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.User

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.User

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.User

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.User

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.User

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.User

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.User

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.User

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.User

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the User queries.

func ByAPIKeys

func ByAPIKeys(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByAPIKeys orders the results by api_keys terms.

func ByAPIKeysCount

func ByAPIKeysCount(opts ...sql.OrderTermOption) OrderOption

ByAPIKeysCount orders the results by api_keys count.

func ByActivatedOn

func ByActivatedOn(opts ...sql.OrderTermOption) OrderOption

ByActivatedOn orders the results by the activated_on field.

func ByAuthTokens

func ByAuthTokens(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByAuthTokens orders the results by auth_tokens terms.

func ByAuthTokensCount

func ByAuthTokensCount(opts ...sql.OrderTermOption) OrderOption

ByAuthTokensCount orders the results by auth_tokens count.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByDefaultGroupID

func ByDefaultGroupID(opts ...sql.OrderTermOption) OrderOption

ByDefaultGroupID orders the results by the default_group_id field.

func ByEmail

func ByEmail(opts ...sql.OrderTermOption) OrderOption

ByEmail orders the results by the email field.

func ByGroups

func ByGroups(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByGroups orders the results by groups terms.

func ByGroupsCount

func ByGroupsCount(opts ...sql.OrderTermOption) OrderOption

ByGroupsCount orders the results by groups count.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByIsSuperuser

func ByIsSuperuser(opts ...sql.OrderTermOption) OrderOption

ByIsSuperuser orders the results by the is_superuser field.

func ByName

func ByName(opts ...sql.OrderTermOption) OrderOption

ByName orders the results by the name field.

func ByNotifiers

func ByNotifiers(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByNotifiers orders the results by notifiers terms.

func ByNotifiersCount

func ByNotifiersCount(opts ...sql.OrderTermOption) OrderOption

ByNotifiersCount orders the results by notifiers count.

func ByOidcIssuer

func ByOidcIssuer(opts ...sql.OrderTermOption) OrderOption

ByOidcIssuer orders the results by the oidc_issuer field.

func ByOidcSubject

func ByOidcSubject(opts ...sql.OrderTermOption) OrderOption

ByOidcSubject orders the results by the oidc_subject field.

func ByPassword

func ByPassword(opts ...sql.OrderTermOption) OrderOption

ByPassword orders the results by the password field.

func ByPasswordResetTokens

func ByPasswordResetTokens(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByPasswordResetTokens orders the results by password_reset_tokens terms.

func ByPasswordResetTokensCount

func ByPasswordResetTokensCount(opts ...sql.OrderTermOption) OrderOption

ByPasswordResetTokensCount orders the results by password_reset_tokens count.

func BySuperuser

func BySuperuser(opts ...sql.OrderTermOption) OrderOption

BySuperuser orders the results by the superuser field.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

func ByUserGroups

func ByUserGroups(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByUserGroups orders the results by user_groups terms.

func ByUserGroupsCount

func ByUserGroupsCount(opts ...sql.OrderTermOption) OrderOption

ByUserGroupsCount orders the results by user_groups count.

Jump to