Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Entity) predicate.Entity
- func Archived(v bool) predicate.Entity
- func ArchivedEQ(v bool) predicate.Entity
- func ArchivedNEQ(v bool) predicate.Entity
- func AssetID(v int64) predicate.Entity
- func AssetIDEQ(v int64) predicate.Entity
- func AssetIDGT(v int64) predicate.Entity
- func AssetIDGTE(v int64) predicate.Entity
- func AssetIDIn(vs ...int64) predicate.Entity
- func AssetIDLT(v int64) predicate.Entity
- func AssetIDLTE(v int64) predicate.Entity
- func AssetIDNEQ(v int64) predicate.Entity
- func AssetIDNotIn(vs ...int64) predicate.Entity
- func CreatedAt(v time.Time) predicate.Entity
- func CreatedAtEQ(v time.Time) predicate.Entity
- func CreatedAtGT(v time.Time) predicate.Entity
- func CreatedAtGTE(v time.Time) predicate.Entity
- func CreatedAtIn(vs ...time.Time) predicate.Entity
- func CreatedAtLT(v time.Time) predicate.Entity
- func CreatedAtLTE(v time.Time) predicate.Entity
- func CreatedAtNEQ(v time.Time) predicate.Entity
- func CreatedAtNotIn(vs ...time.Time) predicate.Entity
- func Description(v string) predicate.Entity
- func DescriptionContains(v string) predicate.Entity
- func DescriptionContainsFold(v string) predicate.Entity
- func DescriptionEQ(v string) predicate.Entity
- func DescriptionEqualFold(v string) predicate.Entity
- func DescriptionGT(v string) predicate.Entity
- func DescriptionGTE(v string) predicate.Entity
- func DescriptionHasPrefix(v string) predicate.Entity
- func DescriptionHasSuffix(v string) predicate.Entity
- func DescriptionIn(vs ...string) predicate.Entity
- func DescriptionIsNil() predicate.Entity
- func DescriptionLT(v string) predicate.Entity
- func DescriptionLTE(v string) predicate.Entity
- func DescriptionNEQ(v string) predicate.Entity
- func DescriptionNotIn(vs ...string) predicate.Entity
- func DescriptionNotNil() predicate.Entity
- func HasAttachments() predicate.Entity
- func HasAttachmentsWith(preds ...predicate.Attachment) predicate.Entity
- func HasChildren() predicate.Entity
- func HasChildrenWith(preds ...predicate.Entity) predicate.Entity
- func HasEntityType() predicate.Entity
- func HasEntityTypeWith(preds ...predicate.EntityType) predicate.Entity
- func HasFields() predicate.Entity
- func HasFieldsWith(preds ...predicate.EntityField) predicate.Entity
- func HasGroup() predicate.Entity
- func HasGroupWith(preds ...predicate.Group) predicate.Entity
- func HasMaintenanceEntries() predicate.Entity
- func HasMaintenanceEntriesWith(preds ...predicate.MaintenanceEntry) predicate.Entity
- func HasParent() predicate.Entity
- func HasParentWith(preds ...predicate.Entity) predicate.Entity
- func HasTag() predicate.Entity
- func HasTagWith(preds ...predicate.Tag) predicate.Entity
- func ID(id uuid.UUID) predicate.Entity
- func IDEQ(id uuid.UUID) predicate.Entity
- func IDGT(id uuid.UUID) predicate.Entity
- func IDGTE(id uuid.UUID) predicate.Entity
- func IDIn(ids ...uuid.UUID) predicate.Entity
- func IDLT(id uuid.UUID) predicate.Entity
- func IDLTE(id uuid.UUID) predicate.Entity
- func IDNEQ(id uuid.UUID) predicate.Entity
- func IDNotIn(ids ...uuid.UUID) predicate.Entity
- func ImportRef(v string) predicate.Entity
- func ImportRefContains(v string) predicate.Entity
- func ImportRefContainsFold(v string) predicate.Entity
- func ImportRefEQ(v string) predicate.Entity
- func ImportRefEqualFold(v string) predicate.Entity
- func ImportRefGT(v string) predicate.Entity
- func ImportRefGTE(v string) predicate.Entity
- func ImportRefHasPrefix(v string) predicate.Entity
- func ImportRefHasSuffix(v string) predicate.Entity
- func ImportRefIn(vs ...string) predicate.Entity
- func ImportRefIsNil() predicate.Entity
- func ImportRefLT(v string) predicate.Entity
- func ImportRefLTE(v string) predicate.Entity
- func ImportRefNEQ(v string) predicate.Entity
- func ImportRefNotIn(vs ...string) predicate.Entity
- func ImportRefNotNil() predicate.Entity
- func Insured(v bool) predicate.Entity
- func InsuredEQ(v bool) predicate.Entity
- func InsuredNEQ(v bool) predicate.Entity
- func LifetimeWarranty(v bool) predicate.Entity
- func LifetimeWarrantyEQ(v bool) predicate.Entity
- func LifetimeWarrantyNEQ(v bool) predicate.Entity
- func Manufacturer(v string) predicate.Entity
- func ManufacturerContains(v string) predicate.Entity
- func ManufacturerContainsFold(v string) predicate.Entity
- func ManufacturerEQ(v string) predicate.Entity
- func ManufacturerEqualFold(v string) predicate.Entity
- func ManufacturerGT(v string) predicate.Entity
- func ManufacturerGTE(v string) predicate.Entity
- func ManufacturerHasPrefix(v string) predicate.Entity
- func ManufacturerHasSuffix(v string) predicate.Entity
- func ManufacturerIn(vs ...string) predicate.Entity
- func ManufacturerIsNil() predicate.Entity
- func ManufacturerLT(v string) predicate.Entity
- func ManufacturerLTE(v string) predicate.Entity
- func ManufacturerNEQ(v string) predicate.Entity
- func ManufacturerNotIn(vs ...string) predicate.Entity
- func ManufacturerNotNil() predicate.Entity
- func ModelNumber(v string) predicate.Entity
- func ModelNumberContains(v string) predicate.Entity
- func ModelNumberContainsFold(v string) predicate.Entity
- func ModelNumberEQ(v string) predicate.Entity
- func ModelNumberEqualFold(v string) predicate.Entity
- func ModelNumberGT(v string) predicate.Entity
- func ModelNumberGTE(v string) predicate.Entity
- func ModelNumberHasPrefix(v string) predicate.Entity
- func ModelNumberHasSuffix(v string) predicate.Entity
- func ModelNumberIn(vs ...string) predicate.Entity
- func ModelNumberIsNil() predicate.Entity
- func ModelNumberLT(v string) predicate.Entity
- func ModelNumberLTE(v string) predicate.Entity
- func ModelNumberNEQ(v string) predicate.Entity
- func ModelNumberNotIn(vs ...string) predicate.Entity
- func ModelNumberNotNil() predicate.Entity
- func Name(v string) predicate.Entity
- func NameContains(v string) predicate.Entity
- func NameContainsFold(v string) predicate.Entity
- func NameEQ(v string) predicate.Entity
- func NameEqualFold(v string) predicate.Entity
- func NameGT(v string) predicate.Entity
- func NameGTE(v string) predicate.Entity
- func NameHasPrefix(v string) predicate.Entity
- func NameHasSuffix(v string) predicate.Entity
- func NameIn(vs ...string) predicate.Entity
- func NameLT(v string) predicate.Entity
- func NameLTE(v string) predicate.Entity
- func NameNEQ(v string) predicate.Entity
- func NameNotIn(vs ...string) predicate.Entity
- func Not(p predicate.Entity) predicate.Entity
- func Notes(v string) predicate.Entity
- func NotesContains(v string) predicate.Entity
- func NotesContainsFold(v string) predicate.Entity
- func NotesEQ(v string) predicate.Entity
- func NotesEqualFold(v string) predicate.Entity
- func NotesGT(v string) predicate.Entity
- func NotesGTE(v string) predicate.Entity
- func NotesHasPrefix(v string) predicate.Entity
- func NotesHasSuffix(v string) predicate.Entity
- func NotesIn(vs ...string) predicate.Entity
- func NotesIsNil() predicate.Entity
- func NotesLT(v string) predicate.Entity
- func NotesLTE(v string) predicate.Entity
- func NotesNEQ(v string) predicate.Entity
- func NotesNotIn(vs ...string) predicate.Entity
- func NotesNotNil() predicate.Entity
- func Or(predicates ...predicate.Entity) predicate.Entity
- func PurchaseDate(v time.Time) predicate.Entity
- func PurchaseDateEQ(v time.Time) predicate.Entity
- func PurchaseDateGT(v time.Time) predicate.Entity
- func PurchaseDateGTE(v time.Time) predicate.Entity
- func PurchaseDateIn(vs ...time.Time) predicate.Entity
- func PurchaseDateIsNil() predicate.Entity
- func PurchaseDateLT(v time.Time) predicate.Entity
- func PurchaseDateLTE(v time.Time) predicate.Entity
- func PurchaseDateNEQ(v time.Time) predicate.Entity
- func PurchaseDateNotIn(vs ...time.Time) predicate.Entity
- func PurchaseDateNotNil() predicate.Entity
- func PurchaseFrom(v string) predicate.Entity
- func PurchaseFromContains(v string) predicate.Entity
- func PurchaseFromContainsFold(v string) predicate.Entity
- func PurchaseFromEQ(v string) predicate.Entity
- func PurchaseFromEqualFold(v string) predicate.Entity
- func PurchaseFromGT(v string) predicate.Entity
- func PurchaseFromGTE(v string) predicate.Entity
- func PurchaseFromHasPrefix(v string) predicate.Entity
- func PurchaseFromHasSuffix(v string) predicate.Entity
- func PurchaseFromIn(vs ...string) predicate.Entity
- func PurchaseFromIsNil() predicate.Entity
- func PurchaseFromLT(v string) predicate.Entity
- func PurchaseFromLTE(v string) predicate.Entity
- func PurchaseFromNEQ(v string) predicate.Entity
- func PurchaseFromNotIn(vs ...string) predicate.Entity
- func PurchaseFromNotNil() predicate.Entity
- func PurchasePrice(v float64) predicate.Entity
- func PurchasePriceEQ(v float64) predicate.Entity
- func PurchasePriceGT(v float64) predicate.Entity
- func PurchasePriceGTE(v float64) predicate.Entity
- func PurchasePriceIn(vs ...float64) predicate.Entity
- func PurchasePriceLT(v float64) predicate.Entity
- func PurchasePriceLTE(v float64) predicate.Entity
- func PurchasePriceNEQ(v float64) predicate.Entity
- func PurchasePriceNotIn(vs ...float64) predicate.Entity
- func Quantity(v float64) predicate.Entity
- func QuantityEQ(v float64) predicate.Entity
- func QuantityGT(v float64) predicate.Entity
- func QuantityGTE(v float64) predicate.Entity
- func QuantityIn(vs ...float64) predicate.Entity
- func QuantityLT(v float64) predicate.Entity
- func QuantityLTE(v float64) predicate.Entity
- func QuantityNEQ(v float64) predicate.Entity
- func QuantityNotIn(vs ...float64) predicate.Entity
- func SerialNumber(v string) predicate.Entity
- func SerialNumberContains(v string) predicate.Entity
- func SerialNumberContainsFold(v string) predicate.Entity
- func SerialNumberEQ(v string) predicate.Entity
- func SerialNumberEqualFold(v string) predicate.Entity
- func SerialNumberGT(v string) predicate.Entity
- func SerialNumberGTE(v string) predicate.Entity
- func SerialNumberHasPrefix(v string) predicate.Entity
- func SerialNumberHasSuffix(v string) predicate.Entity
- func SerialNumberIn(vs ...string) predicate.Entity
- func SerialNumberIsNil() predicate.Entity
- func SerialNumberLT(v string) predicate.Entity
- func SerialNumberLTE(v string) predicate.Entity
- func SerialNumberNEQ(v string) predicate.Entity
- func SerialNumberNotIn(vs ...string) predicate.Entity
- func SerialNumberNotNil() predicate.Entity
- func SoldDate(v time.Time) predicate.Entity
- func SoldDateEQ(v time.Time) predicate.Entity
- func SoldDateGT(v time.Time) predicate.Entity
- func SoldDateGTE(v time.Time) predicate.Entity
- func SoldDateIn(vs ...time.Time) predicate.Entity
- func SoldDateIsNil() predicate.Entity
- func SoldDateLT(v time.Time) predicate.Entity
- func SoldDateLTE(v time.Time) predicate.Entity
- func SoldDateNEQ(v time.Time) predicate.Entity
- func SoldDateNotIn(vs ...time.Time) predicate.Entity
- func SoldDateNotNil() predicate.Entity
- func SoldNotes(v string) predicate.Entity
- func SoldNotesContains(v string) predicate.Entity
- func SoldNotesContainsFold(v string) predicate.Entity
- func SoldNotesEQ(v string) predicate.Entity
- func SoldNotesEqualFold(v string) predicate.Entity
- func SoldNotesGT(v string) predicate.Entity
- func SoldNotesGTE(v string) predicate.Entity
- func SoldNotesHasPrefix(v string) predicate.Entity
- func SoldNotesHasSuffix(v string) predicate.Entity
- func SoldNotesIn(vs ...string) predicate.Entity
- func SoldNotesIsNil() predicate.Entity
- func SoldNotesLT(v string) predicate.Entity
- func SoldNotesLTE(v string) predicate.Entity
- func SoldNotesNEQ(v string) predicate.Entity
- func SoldNotesNotIn(vs ...string) predicate.Entity
- func SoldNotesNotNil() predicate.Entity
- func SoldPrice(v float64) predicate.Entity
- func SoldPriceEQ(v float64) predicate.Entity
- func SoldPriceGT(v float64) predicate.Entity
- func SoldPriceGTE(v float64) predicate.Entity
- func SoldPriceIn(vs ...float64) predicate.Entity
- func SoldPriceLT(v float64) predicate.Entity
- func SoldPriceLTE(v float64) predicate.Entity
- func SoldPriceNEQ(v float64) predicate.Entity
- func SoldPriceNotIn(vs ...float64) predicate.Entity
- func SoldTo(v string) predicate.Entity
- func SoldToContains(v string) predicate.Entity
- func SoldToContainsFold(v string) predicate.Entity
- func SoldToEQ(v string) predicate.Entity
- func SoldToEqualFold(v string) predicate.Entity
- func SoldToGT(v string) predicate.Entity
- func SoldToGTE(v string) predicate.Entity
- func SoldToHasPrefix(v string) predicate.Entity
- func SoldToHasSuffix(v string) predicate.Entity
- func SoldToIn(vs ...string) predicate.Entity
- func SoldToIsNil() predicate.Entity
- func SoldToLT(v string) predicate.Entity
- func SoldToLTE(v string) predicate.Entity
- func SoldToNEQ(v string) predicate.Entity
- func SoldToNotIn(vs ...string) predicate.Entity
- func SoldToNotNil() predicate.Entity
- func SyncChildEntityLocations(v bool) predicate.Entity
- func SyncChildEntityLocationsEQ(v bool) predicate.Entity
- func SyncChildEntityLocationsNEQ(v bool) predicate.Entity
- func UpdatedAt(v time.Time) predicate.Entity
- func UpdatedAtEQ(v time.Time) predicate.Entity
- func UpdatedAtGT(v time.Time) predicate.Entity
- func UpdatedAtGTE(v time.Time) predicate.Entity
- func UpdatedAtIn(vs ...time.Time) predicate.Entity
- func UpdatedAtLT(v time.Time) predicate.Entity
- func UpdatedAtLTE(v time.Time) predicate.Entity
- func UpdatedAtNEQ(v time.Time) predicate.Entity
- func UpdatedAtNotIn(vs ...time.Time) predicate.Entity
- func ValidColumn(column string) bool
- func WarrantyDetails(v string) predicate.Entity
- func WarrantyDetailsContains(v string) predicate.Entity
- func WarrantyDetailsContainsFold(v string) predicate.Entity
- func WarrantyDetailsEQ(v string) predicate.Entity
- func WarrantyDetailsEqualFold(v string) predicate.Entity
- func WarrantyDetailsGT(v string) predicate.Entity
- func WarrantyDetailsGTE(v string) predicate.Entity
- func WarrantyDetailsHasPrefix(v string) predicate.Entity
- func WarrantyDetailsHasSuffix(v string) predicate.Entity
- func WarrantyDetailsIn(vs ...string) predicate.Entity
- func WarrantyDetailsIsNil() predicate.Entity
- func WarrantyDetailsLT(v string) predicate.Entity
- func WarrantyDetailsLTE(v string) predicate.Entity
- func WarrantyDetailsNEQ(v string) predicate.Entity
- func WarrantyDetailsNotIn(vs ...string) predicate.Entity
- func WarrantyDetailsNotNil() predicate.Entity
- func WarrantyExpires(v time.Time) predicate.Entity
- func WarrantyExpiresEQ(v time.Time) predicate.Entity
- func WarrantyExpiresGT(v time.Time) predicate.Entity
- func WarrantyExpiresGTE(v time.Time) predicate.Entity
- func WarrantyExpiresIn(vs ...time.Time) predicate.Entity
- func WarrantyExpiresIsNil() predicate.Entity
- func WarrantyExpiresLT(v time.Time) predicate.Entity
- func WarrantyExpiresLTE(v time.Time) predicate.Entity
- func WarrantyExpiresNEQ(v time.Time) predicate.Entity
- func WarrantyExpiresNotIn(vs ...time.Time) predicate.Entity
- func WarrantyExpiresNotNil() predicate.Entity
- type OrderOption
- func ByArchived(opts ...sql.OrderTermOption) OrderOption
- func ByAssetID(opts ...sql.OrderTermOption) OrderOption
- func ByAttachments(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByAttachmentsCount(opts ...sql.OrderTermOption) OrderOption
- func ByChildren(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByChildrenCount(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByDescription(opts ...sql.OrderTermOption) OrderOption
- func ByEntityTypeField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByFields(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByFieldsCount(opts ...sql.OrderTermOption) OrderOption
- func ByGroupField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByImportRef(opts ...sql.OrderTermOption) OrderOption
- func ByInsured(opts ...sql.OrderTermOption) OrderOption
- func ByLifetimeWarranty(opts ...sql.OrderTermOption) OrderOption
- func ByMaintenanceEntries(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByMaintenanceEntriesCount(opts ...sql.OrderTermOption) OrderOption
- func ByManufacturer(opts ...sql.OrderTermOption) OrderOption
- func ByModelNumber(opts ...sql.OrderTermOption) OrderOption
- func ByName(opts ...sql.OrderTermOption) OrderOption
- func ByNotes(opts ...sql.OrderTermOption) OrderOption
- func ByParentField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByPurchaseDate(opts ...sql.OrderTermOption) OrderOption
- func ByPurchaseFrom(opts ...sql.OrderTermOption) OrderOption
- func ByPurchasePrice(opts ...sql.OrderTermOption) OrderOption
- func ByQuantity(opts ...sql.OrderTermOption) OrderOption
- func BySerialNumber(opts ...sql.OrderTermOption) OrderOption
- func BySoldDate(opts ...sql.OrderTermOption) OrderOption
- func BySoldNotes(opts ...sql.OrderTermOption) OrderOption
- func BySoldPrice(opts ...sql.OrderTermOption) OrderOption
- func BySoldTo(opts ...sql.OrderTermOption) OrderOption
- func BySyncChildEntityLocations(opts ...sql.OrderTermOption) OrderOption
- func ByTag(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByTagCount(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByWarrantyDetails(opts ...sql.OrderTermOption) OrderOption
- func ByWarrantyExpires(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the entity type in the database. Label = "entity" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldDescription holds the string denoting the description field in the database. FieldDescription = "description" // FieldImportRef holds the string denoting the import_ref field in the database. FieldImportRef = "import_ref" // FieldNotes holds the string denoting the notes field in the database. FieldNotes = "notes" // FieldQuantity holds the string denoting the quantity field in the database. FieldQuantity = "quantity" // FieldInsured holds the string denoting the insured field in the database. FieldInsured = "insured" // FieldArchived holds the string denoting the archived field in the database. FieldArchived = "archived" // FieldAssetID holds the string denoting the asset_id field in the database. FieldAssetID = "asset_id" // FieldSyncChildEntityLocations holds the string denoting the sync_child_entity_locations field in the database. FieldSyncChildEntityLocations = "sync_child_entity_locations" // FieldSerialNumber holds the string denoting the serial_number field in the database. FieldSerialNumber = "serial_number" // FieldModelNumber holds the string denoting the model_number field in the database. FieldModelNumber = "model_number" // FieldManufacturer holds the string denoting the manufacturer field in the database. FieldManufacturer = "manufacturer" // FieldLifetimeWarranty holds the string denoting the lifetime_warranty field in the database. FieldLifetimeWarranty = "lifetime_warranty" // FieldWarrantyExpires holds the string denoting the warranty_expires field in the database. FieldWarrantyExpires = "warranty_expires" // FieldWarrantyDetails holds the string denoting the warranty_details field in the database. FieldWarrantyDetails = "warranty_details" // FieldPurchaseDate holds the string denoting the purchase_date field in the database. FieldPurchaseDate = "purchase_date" // FieldPurchaseFrom holds the string denoting the purchase_from field in the database. FieldPurchaseFrom = "purchase_from" // FieldPurchasePrice holds the string denoting the purchase_price field in the database. FieldPurchasePrice = "purchase_price" // FieldSoldDate holds the string denoting the sold_date field in the database. FieldSoldDate = "sold_date" // FieldSoldTo holds the string denoting the sold_to field in the database. FieldSoldTo = "sold_to" // FieldSoldPrice holds the string denoting the sold_price field in the database. FieldSoldPrice = "sold_price" // FieldSoldNotes holds the string denoting the sold_notes field in the database. FieldSoldNotes = "sold_notes" // EdgeGroup holds the string denoting the group edge name in mutations. EdgeGroup = "group" // EdgeParent holds the string denoting the parent edge name in mutations. EdgeParent = "parent" // EdgeChildren holds the string denoting the children edge name in mutations. EdgeChildren = "children" // EdgeTag holds the string denoting the tag edge name in mutations. EdgeTag = "tag" // EdgeEntityType holds the string denoting the entity_type edge name in mutations. EdgeEntityType = "entity_type" // EdgeFields holds the string denoting the fields edge name in mutations. EdgeFields = "fields" // EdgeMaintenanceEntries holds the string denoting the maintenance_entries edge name in mutations. EdgeMaintenanceEntries = "maintenance_entries" // EdgeAttachments holds the string denoting the attachments edge name in mutations. EdgeAttachments = "attachments" // Table holds the table name of the entity in the database. Table = "entities" // GroupTable is the table that holds the group relation/edge. GroupTable = "entities" // GroupInverseTable is the table name for the Group entity. // It exists in this package in order to avoid circular dependency with the "group" package. GroupInverseTable = "groups" // GroupColumn is the table column denoting the group relation/edge. GroupColumn = "group_entities" // ParentTable is the table that holds the parent relation/edge. ParentTable = "entities" // ParentColumn is the table column denoting the parent relation/edge. ParentColumn = "entity_children" // ChildrenTable is the table that holds the children relation/edge. ChildrenTable = "entities" // ChildrenColumn is the table column denoting the children relation/edge. ChildrenColumn = "entity_children" // TagTable is the table that holds the tag relation/edge. The primary key declared below. TagTable = "tag_entities" // TagInverseTable is the table name for the Tag entity. // It exists in this package in order to avoid circular dependency with the "tag" package. TagInverseTable = "tags" // EntityTypeTable is the table that holds the entity_type relation/edge. EntityTypeTable = "entities" // EntityTypeInverseTable is the table name for the EntityType entity. // It exists in this package in order to avoid circular dependency with the "entitytype" package. EntityTypeInverseTable = "entity_types" // EntityTypeColumn is the table column denoting the entity_type relation/edge. EntityTypeColumn = "entity_type_entities" // FieldsTable is the table that holds the fields relation/edge. FieldsTable = "entity_fields" // FieldsInverseTable is the table name for the EntityField entity. // It exists in this package in order to avoid circular dependency with the "entityfield" package. FieldsInverseTable = "entity_fields" // FieldsColumn is the table column denoting the fields relation/edge. FieldsColumn = "entity_fields" // MaintenanceEntriesTable is the table that holds the maintenance_entries relation/edge. MaintenanceEntriesTable = "maintenance_entries" // MaintenanceEntriesInverseTable is the table name for the MaintenanceEntry entity. // It exists in this package in order to avoid circular dependency with the "maintenanceentry" package. MaintenanceEntriesInverseTable = "maintenance_entries" // MaintenanceEntriesColumn is the table column denoting the maintenance_entries relation/edge. MaintenanceEntriesColumn = "entity_id" // AttachmentsTable is the table that holds the attachments relation/edge. AttachmentsTable = "attachments" // AttachmentsInverseTable is the table name for the Attachment entity. // It exists in this package in order to avoid circular dependency with the "attachment" package. AttachmentsInverseTable = "attachments" // AttachmentsColumn is the table column denoting the attachments relation/edge. AttachmentsColumn = "entity_attachments" )
Variables ¶
var ( // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // NameValidator is a validator for the "name" field. It is called by the builders before save. NameValidator func(string) error // DescriptionValidator is a validator for the "description" field. It is called by the builders before save. DescriptionValidator func(string) error // ImportRefValidator is a validator for the "import_ref" field. It is called by the builders before save. ImportRefValidator func(string) error // NotesValidator is a validator for the "notes" field. It is called by the builders before save. NotesValidator func(string) error // DefaultQuantity holds the default value on creation for the "quantity" field. DefaultQuantity float64 // DefaultInsured holds the default value on creation for the "insured" field. DefaultInsured bool // DefaultArchived holds the default value on creation for the "archived" field. DefaultArchived bool // DefaultAssetID holds the default value on creation for the "asset_id" field. DefaultAssetID int64 // DefaultSyncChildEntityLocations holds the default value on creation for the "sync_child_entity_locations" field. DefaultSyncChildEntityLocations bool // SerialNumberValidator is a validator for the "serial_number" field. It is called by the builders before save. SerialNumberValidator func(string) error // ModelNumberValidator is a validator for the "model_number" field. It is called by the builders before save. ModelNumberValidator func(string) error // ManufacturerValidator is a validator for the "manufacturer" field. It is called by the builders before save. ManufacturerValidator func(string) error // DefaultLifetimeWarranty holds the default value on creation for the "lifetime_warranty" field. DefaultLifetimeWarranty bool // WarrantyDetailsValidator is a validator for the "warranty_details" field. It is called by the builders before save. WarrantyDetailsValidator func(string) error // DefaultPurchasePrice holds the default value on creation for the "purchase_price" field. DefaultPurchasePrice float64 // DefaultSoldPrice holds the default value on creation for the "sold_price" field. DefaultSoldPrice float64 // SoldNotesValidator is a validator for the "sold_notes" field. It is called by the builders before save. SoldNotesValidator func(string) error // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
var Columns = []string{ FieldID, FieldCreatedAt, FieldUpdatedAt, FieldName, FieldDescription, FieldImportRef, FieldNotes, FieldQuantity, FieldInsured, FieldArchived, FieldAssetID, FieldSyncChildEntityLocations, FieldSerialNumber, FieldModelNumber, FieldManufacturer, FieldLifetimeWarranty, FieldWarrantyExpires, FieldWarrantyDetails, FieldPurchaseDate, FieldPurchaseFrom, FieldPurchasePrice, FieldSoldDate, FieldSoldTo, FieldSoldPrice, FieldSoldNotes, }
Columns holds all SQL columns for entity fields.
var ForeignKeys = []string{
"entity_children",
"entity_type_entities",
"group_entities",
}
ForeignKeys holds the SQL foreign-keys that are owned by the "entities" table and are not defined as standalone fields in the schema.
var ( // TagPrimaryKey and TagColumn2 are the table columns denoting the // primary key for the tag relation (M2M). TagPrimaryKey = []string{"tag_id", "entity_id"} )
Functions ¶
func Archived ¶
Archived applies equality check predicate on the "archived" field. It's identical to ArchivedEQ.
func ArchivedEQ ¶
ArchivedEQ applies the EQ predicate on the "archived" field.
func ArchivedNEQ ¶
ArchivedNEQ applies the NEQ predicate on the "archived" field.
func AssetID ¶
AssetID applies equality check predicate on the "asset_id" field. It's identical to AssetIDEQ.
func AssetIDGTE ¶
AssetIDGTE applies the GTE predicate on the "asset_id" field.
func AssetIDLTE ¶
AssetIDLTE applies the LTE predicate on the "asset_id" field.
func AssetIDNEQ ¶
AssetIDNEQ applies the NEQ predicate on the "asset_id" field.
func AssetIDNotIn ¶
AssetIDNotIn applies the NotIn predicate on the "asset_id" field.
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func Description ¶
Description applies equality check predicate on the "description" field. It's identical to DescriptionEQ.
func DescriptionContains ¶
DescriptionContains applies the Contains predicate on the "description" field.
func DescriptionContainsFold ¶
DescriptionContainsFold applies the ContainsFold predicate on the "description" field.
func DescriptionEQ ¶
DescriptionEQ applies the EQ predicate on the "description" field.
func DescriptionEqualFold ¶
DescriptionEqualFold applies the EqualFold predicate on the "description" field.
func DescriptionGT ¶
DescriptionGT applies the GT predicate on the "description" field.
func DescriptionGTE ¶
DescriptionGTE applies the GTE predicate on the "description" field.
func DescriptionHasPrefix ¶
DescriptionHasPrefix applies the HasPrefix predicate on the "description" field.
func DescriptionHasSuffix ¶
DescriptionHasSuffix applies the HasSuffix predicate on the "description" field.
func DescriptionIn ¶
DescriptionIn applies the In predicate on the "description" field.
func DescriptionIsNil ¶
DescriptionIsNil applies the IsNil predicate on the "description" field.
func DescriptionLT ¶
DescriptionLT applies the LT predicate on the "description" field.
func DescriptionLTE ¶
DescriptionLTE applies the LTE predicate on the "description" field.
func DescriptionNEQ ¶
DescriptionNEQ applies the NEQ predicate on the "description" field.
func DescriptionNotIn ¶
DescriptionNotIn applies the NotIn predicate on the "description" field.
func DescriptionNotNil ¶
DescriptionNotNil applies the NotNil predicate on the "description" field.
func HasAttachments ¶
HasAttachments applies the HasEdge predicate on the "attachments" edge.
func HasAttachmentsWith ¶
func HasAttachmentsWith(preds ...predicate.Attachment) predicate.Entity
HasAttachmentsWith applies the HasEdge predicate on the "attachments" edge with a given conditions (other predicates).
func HasChildren ¶
HasChildren applies the HasEdge predicate on the "children" edge.
func HasChildrenWith ¶
HasChildrenWith applies the HasEdge predicate on the "children" edge with a given conditions (other predicates).
func HasEntityType ¶
HasEntityType applies the HasEdge predicate on the "entity_type" edge.
func HasEntityTypeWith ¶
func HasEntityTypeWith(preds ...predicate.EntityType) predicate.Entity
HasEntityTypeWith applies the HasEdge predicate on the "entity_type" edge with a given conditions (other predicates).
func HasFieldsWith ¶
func HasFieldsWith(preds ...predicate.EntityField) predicate.Entity
HasFieldsWith applies the HasEdge predicate on the "fields" edge with a given conditions (other predicates).
func HasGroupWith ¶
HasGroupWith applies the HasEdge predicate on the "group" edge with a given conditions (other predicates).
func HasMaintenanceEntries ¶
HasMaintenanceEntries applies the HasEdge predicate on the "maintenance_entries" edge.
func HasMaintenanceEntriesWith ¶
func HasMaintenanceEntriesWith(preds ...predicate.MaintenanceEntry) predicate.Entity
HasMaintenanceEntriesWith applies the HasEdge predicate on the "maintenance_entries" edge with a given conditions (other predicates).
func HasParentWith ¶
HasParentWith applies the HasEdge predicate on the "parent" edge with a given conditions (other predicates).
func HasTagWith ¶
HasTagWith applies the HasEdge predicate on the "tag" edge with a given conditions (other predicates).
func ImportRef ¶
ImportRef applies equality check predicate on the "import_ref" field. It's identical to ImportRefEQ.
func ImportRefContains ¶
ImportRefContains applies the Contains predicate on the "import_ref" field.
func ImportRefContainsFold ¶
ImportRefContainsFold applies the ContainsFold predicate on the "import_ref" field.
func ImportRefEQ ¶
ImportRefEQ applies the EQ predicate on the "import_ref" field.
func ImportRefEqualFold ¶
ImportRefEqualFold applies the EqualFold predicate on the "import_ref" field.
func ImportRefGT ¶
ImportRefGT applies the GT predicate on the "import_ref" field.
func ImportRefGTE ¶
ImportRefGTE applies the GTE predicate on the "import_ref" field.
func ImportRefHasPrefix ¶
ImportRefHasPrefix applies the HasPrefix predicate on the "import_ref" field.
func ImportRefHasSuffix ¶
ImportRefHasSuffix applies the HasSuffix predicate on the "import_ref" field.
func ImportRefIn ¶
ImportRefIn applies the In predicate on the "import_ref" field.
func ImportRefIsNil ¶
ImportRefIsNil applies the IsNil predicate on the "import_ref" field.
func ImportRefLT ¶
ImportRefLT applies the LT predicate on the "import_ref" field.
func ImportRefLTE ¶
ImportRefLTE applies the LTE predicate on the "import_ref" field.
func ImportRefNEQ ¶
ImportRefNEQ applies the NEQ predicate on the "import_ref" field.
func ImportRefNotIn ¶
ImportRefNotIn applies the NotIn predicate on the "import_ref" field.
func ImportRefNotNil ¶
ImportRefNotNil applies the NotNil predicate on the "import_ref" field.
func Insured ¶
Insured applies equality check predicate on the "insured" field. It's identical to InsuredEQ.
func InsuredNEQ ¶
InsuredNEQ applies the NEQ predicate on the "insured" field.
func LifetimeWarranty ¶
LifetimeWarranty applies equality check predicate on the "lifetime_warranty" field. It's identical to LifetimeWarrantyEQ.
func LifetimeWarrantyEQ ¶
LifetimeWarrantyEQ applies the EQ predicate on the "lifetime_warranty" field.
func LifetimeWarrantyNEQ ¶
LifetimeWarrantyNEQ applies the NEQ predicate on the "lifetime_warranty" field.
func Manufacturer ¶
Manufacturer applies equality check predicate on the "manufacturer" field. It's identical to ManufacturerEQ.
func ManufacturerContains ¶
ManufacturerContains applies the Contains predicate on the "manufacturer" field.
func ManufacturerContainsFold ¶
ManufacturerContainsFold applies the ContainsFold predicate on the "manufacturer" field.
func ManufacturerEQ ¶
ManufacturerEQ applies the EQ predicate on the "manufacturer" field.
func ManufacturerEqualFold ¶
ManufacturerEqualFold applies the EqualFold predicate on the "manufacturer" field.
func ManufacturerGT ¶
ManufacturerGT applies the GT predicate on the "manufacturer" field.
func ManufacturerGTE ¶
ManufacturerGTE applies the GTE predicate on the "manufacturer" field.
func ManufacturerHasPrefix ¶
ManufacturerHasPrefix applies the HasPrefix predicate on the "manufacturer" field.
func ManufacturerHasSuffix ¶
ManufacturerHasSuffix applies the HasSuffix predicate on the "manufacturer" field.
func ManufacturerIn ¶
ManufacturerIn applies the In predicate on the "manufacturer" field.
func ManufacturerIsNil ¶
ManufacturerIsNil applies the IsNil predicate on the "manufacturer" field.
func ManufacturerLT ¶
ManufacturerLT applies the LT predicate on the "manufacturer" field.
func ManufacturerLTE ¶
ManufacturerLTE applies the LTE predicate on the "manufacturer" field.
func ManufacturerNEQ ¶
ManufacturerNEQ applies the NEQ predicate on the "manufacturer" field.
func ManufacturerNotIn ¶
ManufacturerNotIn applies the NotIn predicate on the "manufacturer" field.
func ManufacturerNotNil ¶
ManufacturerNotNil applies the NotNil predicate on the "manufacturer" field.
func ModelNumber ¶
ModelNumber applies equality check predicate on the "model_number" field. It's identical to ModelNumberEQ.
func ModelNumberContains ¶
ModelNumberContains applies the Contains predicate on the "model_number" field.
func ModelNumberContainsFold ¶
ModelNumberContainsFold applies the ContainsFold predicate on the "model_number" field.
func ModelNumberEQ ¶
ModelNumberEQ applies the EQ predicate on the "model_number" field.
func ModelNumberEqualFold ¶
ModelNumberEqualFold applies the EqualFold predicate on the "model_number" field.
func ModelNumberGT ¶
ModelNumberGT applies the GT predicate on the "model_number" field.
func ModelNumberGTE ¶
ModelNumberGTE applies the GTE predicate on the "model_number" field.
func ModelNumberHasPrefix ¶
ModelNumberHasPrefix applies the HasPrefix predicate on the "model_number" field.
func ModelNumberHasSuffix ¶
ModelNumberHasSuffix applies the HasSuffix predicate on the "model_number" field.
func ModelNumberIn ¶
ModelNumberIn applies the In predicate on the "model_number" field.
func ModelNumberIsNil ¶
ModelNumberIsNil applies the IsNil predicate on the "model_number" field.
func ModelNumberLT ¶
ModelNumberLT applies the LT predicate on the "model_number" field.
func ModelNumberLTE ¶
ModelNumberLTE applies the LTE predicate on the "model_number" field.
func ModelNumberNEQ ¶
ModelNumberNEQ applies the NEQ predicate on the "model_number" field.
func ModelNumberNotIn ¶
ModelNumberNotIn applies the NotIn predicate on the "model_number" field.
func ModelNumberNotNil ¶
ModelNumberNotNil applies the NotNil predicate on the "model_number" field.
func NameContains ¶
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEqualFold ¶
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameHasPrefix ¶
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func Notes ¶
Notes applies equality check predicate on the "notes" field. It's identical to NotesEQ.
func NotesContains ¶
NotesContains applies the Contains predicate on the "notes" field.
func NotesContainsFold ¶
NotesContainsFold applies the ContainsFold predicate on the "notes" field.
func NotesEqualFold ¶
NotesEqualFold applies the EqualFold predicate on the "notes" field.
func NotesHasPrefix ¶
NotesHasPrefix applies the HasPrefix predicate on the "notes" field.
func NotesHasSuffix ¶
NotesHasSuffix applies the HasSuffix predicate on the "notes" field.
func NotesIsNil ¶
NotesIsNil applies the IsNil predicate on the "notes" field.
func NotesNotIn ¶
NotesNotIn applies the NotIn predicate on the "notes" field.
func NotesNotNil ¶
NotesNotNil applies the NotNil predicate on the "notes" field.
func PurchaseDate ¶
PurchaseDate applies equality check predicate on the "purchase_date" field. It's identical to PurchaseDateEQ.
func PurchaseDateEQ ¶
PurchaseDateEQ applies the EQ predicate on the "purchase_date" field.
func PurchaseDateGT ¶
PurchaseDateGT applies the GT predicate on the "purchase_date" field.
func PurchaseDateGTE ¶
PurchaseDateGTE applies the GTE predicate on the "purchase_date" field.
func PurchaseDateIn ¶
PurchaseDateIn applies the In predicate on the "purchase_date" field.
func PurchaseDateIsNil ¶
PurchaseDateIsNil applies the IsNil predicate on the "purchase_date" field.
func PurchaseDateLT ¶
PurchaseDateLT applies the LT predicate on the "purchase_date" field.
func PurchaseDateLTE ¶
PurchaseDateLTE applies the LTE predicate on the "purchase_date" field.
func PurchaseDateNEQ ¶
PurchaseDateNEQ applies the NEQ predicate on the "purchase_date" field.
func PurchaseDateNotIn ¶
PurchaseDateNotIn applies the NotIn predicate on the "purchase_date" field.
func PurchaseDateNotNil ¶
PurchaseDateNotNil applies the NotNil predicate on the "purchase_date" field.
func PurchaseFrom ¶
PurchaseFrom applies equality check predicate on the "purchase_from" field. It's identical to PurchaseFromEQ.
func PurchaseFromContains ¶
PurchaseFromContains applies the Contains predicate on the "purchase_from" field.
func PurchaseFromContainsFold ¶
PurchaseFromContainsFold applies the ContainsFold predicate on the "purchase_from" field.
func PurchaseFromEQ ¶
PurchaseFromEQ applies the EQ predicate on the "purchase_from" field.
func PurchaseFromEqualFold ¶
PurchaseFromEqualFold applies the EqualFold predicate on the "purchase_from" field.
func PurchaseFromGT ¶
PurchaseFromGT applies the GT predicate on the "purchase_from" field.
func PurchaseFromGTE ¶
PurchaseFromGTE applies the GTE predicate on the "purchase_from" field.
func PurchaseFromHasPrefix ¶
PurchaseFromHasPrefix applies the HasPrefix predicate on the "purchase_from" field.
func PurchaseFromHasSuffix ¶
PurchaseFromHasSuffix applies the HasSuffix predicate on the "purchase_from" field.
func PurchaseFromIn ¶
PurchaseFromIn applies the In predicate on the "purchase_from" field.
func PurchaseFromIsNil ¶
PurchaseFromIsNil applies the IsNil predicate on the "purchase_from" field.
func PurchaseFromLT ¶
PurchaseFromLT applies the LT predicate on the "purchase_from" field.
func PurchaseFromLTE ¶
PurchaseFromLTE applies the LTE predicate on the "purchase_from" field.
func PurchaseFromNEQ ¶
PurchaseFromNEQ applies the NEQ predicate on the "purchase_from" field.
func PurchaseFromNotIn ¶
PurchaseFromNotIn applies the NotIn predicate on the "purchase_from" field.
func PurchaseFromNotNil ¶
PurchaseFromNotNil applies the NotNil predicate on the "purchase_from" field.
func PurchasePrice ¶
PurchasePrice applies equality check predicate on the "purchase_price" field. It's identical to PurchasePriceEQ.
func PurchasePriceEQ ¶
PurchasePriceEQ applies the EQ predicate on the "purchase_price" field.
func PurchasePriceGT ¶
PurchasePriceGT applies the GT predicate on the "purchase_price" field.
func PurchasePriceGTE ¶
PurchasePriceGTE applies the GTE predicate on the "purchase_price" field.
func PurchasePriceIn ¶
PurchasePriceIn applies the In predicate on the "purchase_price" field.
func PurchasePriceLT ¶
PurchasePriceLT applies the LT predicate on the "purchase_price" field.
func PurchasePriceLTE ¶
PurchasePriceLTE applies the LTE predicate on the "purchase_price" field.
func PurchasePriceNEQ ¶
PurchasePriceNEQ applies the NEQ predicate on the "purchase_price" field.
func PurchasePriceNotIn ¶
PurchasePriceNotIn applies the NotIn predicate on the "purchase_price" field.
func Quantity ¶
Quantity applies equality check predicate on the "quantity" field. It's identical to QuantityEQ.
func QuantityEQ ¶
QuantityEQ applies the EQ predicate on the "quantity" field.
func QuantityGT ¶
QuantityGT applies the GT predicate on the "quantity" field.
func QuantityGTE ¶
QuantityGTE applies the GTE predicate on the "quantity" field.
func QuantityIn ¶
QuantityIn applies the In predicate on the "quantity" field.
func QuantityLT ¶
QuantityLT applies the LT predicate on the "quantity" field.
func QuantityLTE ¶
QuantityLTE applies the LTE predicate on the "quantity" field.
func QuantityNEQ ¶
QuantityNEQ applies the NEQ predicate on the "quantity" field.
func QuantityNotIn ¶
QuantityNotIn applies the NotIn predicate on the "quantity" field.
func SerialNumber ¶
SerialNumber applies equality check predicate on the "serial_number" field. It's identical to SerialNumberEQ.
func SerialNumberContains ¶
SerialNumberContains applies the Contains predicate on the "serial_number" field.
func SerialNumberContainsFold ¶
SerialNumberContainsFold applies the ContainsFold predicate on the "serial_number" field.
func SerialNumberEQ ¶
SerialNumberEQ applies the EQ predicate on the "serial_number" field.
func SerialNumberEqualFold ¶
SerialNumberEqualFold applies the EqualFold predicate on the "serial_number" field.
func SerialNumberGT ¶
SerialNumberGT applies the GT predicate on the "serial_number" field.
func SerialNumberGTE ¶
SerialNumberGTE applies the GTE predicate on the "serial_number" field.
func SerialNumberHasPrefix ¶
SerialNumberHasPrefix applies the HasPrefix predicate on the "serial_number" field.
func SerialNumberHasSuffix ¶
SerialNumberHasSuffix applies the HasSuffix predicate on the "serial_number" field.
func SerialNumberIn ¶
SerialNumberIn applies the In predicate on the "serial_number" field.
func SerialNumberIsNil ¶
SerialNumberIsNil applies the IsNil predicate on the "serial_number" field.
func SerialNumberLT ¶
SerialNumberLT applies the LT predicate on the "serial_number" field.
func SerialNumberLTE ¶
SerialNumberLTE applies the LTE predicate on the "serial_number" field.
func SerialNumberNEQ ¶
SerialNumberNEQ applies the NEQ predicate on the "serial_number" field.
func SerialNumberNotIn ¶
SerialNumberNotIn applies the NotIn predicate on the "serial_number" field.
func SerialNumberNotNil ¶
SerialNumberNotNil applies the NotNil predicate on the "serial_number" field.
func SoldDate ¶
SoldDate applies equality check predicate on the "sold_date" field. It's identical to SoldDateEQ.
func SoldDateEQ ¶
SoldDateEQ applies the EQ predicate on the "sold_date" field.
func SoldDateGT ¶
SoldDateGT applies the GT predicate on the "sold_date" field.
func SoldDateGTE ¶
SoldDateGTE applies the GTE predicate on the "sold_date" field.
func SoldDateIn ¶
SoldDateIn applies the In predicate on the "sold_date" field.
func SoldDateIsNil ¶
SoldDateIsNil applies the IsNil predicate on the "sold_date" field.
func SoldDateLT ¶
SoldDateLT applies the LT predicate on the "sold_date" field.
func SoldDateLTE ¶
SoldDateLTE applies the LTE predicate on the "sold_date" field.
func SoldDateNEQ ¶
SoldDateNEQ applies the NEQ predicate on the "sold_date" field.
func SoldDateNotIn ¶
SoldDateNotIn applies the NotIn predicate on the "sold_date" field.
func SoldDateNotNil ¶
SoldDateNotNil applies the NotNil predicate on the "sold_date" field.
func SoldNotes ¶
SoldNotes applies equality check predicate on the "sold_notes" field. It's identical to SoldNotesEQ.
func SoldNotesContains ¶
SoldNotesContains applies the Contains predicate on the "sold_notes" field.
func SoldNotesContainsFold ¶
SoldNotesContainsFold applies the ContainsFold predicate on the "sold_notes" field.
func SoldNotesEQ ¶
SoldNotesEQ applies the EQ predicate on the "sold_notes" field.
func SoldNotesEqualFold ¶
SoldNotesEqualFold applies the EqualFold predicate on the "sold_notes" field.
func SoldNotesGT ¶
SoldNotesGT applies the GT predicate on the "sold_notes" field.
func SoldNotesGTE ¶
SoldNotesGTE applies the GTE predicate on the "sold_notes" field.
func SoldNotesHasPrefix ¶
SoldNotesHasPrefix applies the HasPrefix predicate on the "sold_notes" field.
func SoldNotesHasSuffix ¶
SoldNotesHasSuffix applies the HasSuffix predicate on the "sold_notes" field.
func SoldNotesIn ¶
SoldNotesIn applies the In predicate on the "sold_notes" field.
func SoldNotesIsNil ¶
SoldNotesIsNil applies the IsNil predicate on the "sold_notes" field.
func SoldNotesLT ¶
SoldNotesLT applies the LT predicate on the "sold_notes" field.
func SoldNotesLTE ¶
SoldNotesLTE applies the LTE predicate on the "sold_notes" field.
func SoldNotesNEQ ¶
SoldNotesNEQ applies the NEQ predicate on the "sold_notes" field.
func SoldNotesNotIn ¶
SoldNotesNotIn applies the NotIn predicate on the "sold_notes" field.
func SoldNotesNotNil ¶
SoldNotesNotNil applies the NotNil predicate on the "sold_notes" field.
func SoldPrice ¶
SoldPrice applies equality check predicate on the "sold_price" field. It's identical to SoldPriceEQ.
func SoldPriceEQ ¶
SoldPriceEQ applies the EQ predicate on the "sold_price" field.
func SoldPriceGT ¶
SoldPriceGT applies the GT predicate on the "sold_price" field.
func SoldPriceGTE ¶
SoldPriceGTE applies the GTE predicate on the "sold_price" field.
func SoldPriceIn ¶
SoldPriceIn applies the In predicate on the "sold_price" field.
func SoldPriceLT ¶
SoldPriceLT applies the LT predicate on the "sold_price" field.
func SoldPriceLTE ¶
SoldPriceLTE applies the LTE predicate on the "sold_price" field.
func SoldPriceNEQ ¶
SoldPriceNEQ applies the NEQ predicate on the "sold_price" field.
func SoldPriceNotIn ¶
SoldPriceNotIn applies the NotIn predicate on the "sold_price" field.
func SoldTo ¶
SoldTo applies equality check predicate on the "sold_to" field. It's identical to SoldToEQ.
func SoldToContains ¶
SoldToContains applies the Contains predicate on the "sold_to" field.
func SoldToContainsFold ¶
SoldToContainsFold applies the ContainsFold predicate on the "sold_to" field.
func SoldToEqualFold ¶
SoldToEqualFold applies the EqualFold predicate on the "sold_to" field.
func SoldToHasPrefix ¶
SoldToHasPrefix applies the HasPrefix predicate on the "sold_to" field.
func SoldToHasSuffix ¶
SoldToHasSuffix applies the HasSuffix predicate on the "sold_to" field.
func SoldToIsNil ¶
SoldToIsNil applies the IsNil predicate on the "sold_to" field.
func SoldToNotIn ¶
SoldToNotIn applies the NotIn predicate on the "sold_to" field.
func SoldToNotNil ¶
SoldToNotNil applies the NotNil predicate on the "sold_to" field.
func SyncChildEntityLocations ¶
SyncChildEntityLocations applies equality check predicate on the "sync_child_entity_locations" field. It's identical to SyncChildEntityLocationsEQ.
func SyncChildEntityLocationsEQ ¶
SyncChildEntityLocationsEQ applies the EQ predicate on the "sync_child_entity_locations" field.
func SyncChildEntityLocationsNEQ ¶
SyncChildEntityLocationsNEQ applies the NEQ predicate on the "sync_child_entity_locations" field.
func UpdatedAt ¶
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
func WarrantyDetails ¶
WarrantyDetails applies equality check predicate on the "warranty_details" field. It's identical to WarrantyDetailsEQ.
func WarrantyDetailsContains ¶
WarrantyDetailsContains applies the Contains predicate on the "warranty_details" field.
func WarrantyDetailsContainsFold ¶
WarrantyDetailsContainsFold applies the ContainsFold predicate on the "warranty_details" field.
func WarrantyDetailsEQ ¶
WarrantyDetailsEQ applies the EQ predicate on the "warranty_details" field.
func WarrantyDetailsEqualFold ¶
WarrantyDetailsEqualFold applies the EqualFold predicate on the "warranty_details" field.
func WarrantyDetailsGT ¶
WarrantyDetailsGT applies the GT predicate on the "warranty_details" field.
func WarrantyDetailsGTE ¶
WarrantyDetailsGTE applies the GTE predicate on the "warranty_details" field.
func WarrantyDetailsHasPrefix ¶
WarrantyDetailsHasPrefix applies the HasPrefix predicate on the "warranty_details" field.
func WarrantyDetailsHasSuffix ¶
WarrantyDetailsHasSuffix applies the HasSuffix predicate on the "warranty_details" field.
func WarrantyDetailsIn ¶
WarrantyDetailsIn applies the In predicate on the "warranty_details" field.
func WarrantyDetailsIsNil ¶
WarrantyDetailsIsNil applies the IsNil predicate on the "warranty_details" field.
func WarrantyDetailsLT ¶
WarrantyDetailsLT applies the LT predicate on the "warranty_details" field.
func WarrantyDetailsLTE ¶
WarrantyDetailsLTE applies the LTE predicate on the "warranty_details" field.
func WarrantyDetailsNEQ ¶
WarrantyDetailsNEQ applies the NEQ predicate on the "warranty_details" field.
func WarrantyDetailsNotIn ¶
WarrantyDetailsNotIn applies the NotIn predicate on the "warranty_details" field.
func WarrantyDetailsNotNil ¶
WarrantyDetailsNotNil applies the NotNil predicate on the "warranty_details" field.
func WarrantyExpires ¶
WarrantyExpires applies equality check predicate on the "warranty_expires" field. It's identical to WarrantyExpiresEQ.
func WarrantyExpiresEQ ¶
WarrantyExpiresEQ applies the EQ predicate on the "warranty_expires" field.
func WarrantyExpiresGT ¶
WarrantyExpiresGT applies the GT predicate on the "warranty_expires" field.
func WarrantyExpiresGTE ¶
WarrantyExpiresGTE applies the GTE predicate on the "warranty_expires" field.
func WarrantyExpiresIn ¶
WarrantyExpiresIn applies the In predicate on the "warranty_expires" field.
func WarrantyExpiresIsNil ¶
WarrantyExpiresIsNil applies the IsNil predicate on the "warranty_expires" field.
func WarrantyExpiresLT ¶
WarrantyExpiresLT applies the LT predicate on the "warranty_expires" field.
func WarrantyExpiresLTE ¶
WarrantyExpiresLTE applies the LTE predicate on the "warranty_expires" field.
func WarrantyExpiresNEQ ¶
WarrantyExpiresNEQ applies the NEQ predicate on the "warranty_expires" field.
func WarrantyExpiresNotIn ¶
WarrantyExpiresNotIn applies the NotIn predicate on the "warranty_expires" field.
func WarrantyExpiresNotNil ¶
WarrantyExpiresNotNil applies the NotNil predicate on the "warranty_expires" field.
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Entity queries.
func ByArchived ¶
func ByArchived(opts ...sql.OrderTermOption) OrderOption
ByArchived orders the results by the archived field.
func ByAssetID ¶
func ByAssetID(opts ...sql.OrderTermOption) OrderOption
ByAssetID orders the results by the asset_id field.
func ByAttachments ¶
func ByAttachments(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByAttachments orders the results by attachments terms.
func ByAttachmentsCount ¶
func ByAttachmentsCount(opts ...sql.OrderTermOption) OrderOption
ByAttachmentsCount orders the results by attachments count.
func ByChildren ¶
func ByChildren(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByChildren orders the results by children terms.
func ByChildrenCount ¶
func ByChildrenCount(opts ...sql.OrderTermOption) OrderOption
ByChildrenCount orders the results by children count.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByDescription ¶
func ByDescription(opts ...sql.OrderTermOption) OrderOption
ByDescription orders the results by the description field.
func ByEntityTypeField ¶
func ByEntityTypeField(field string, opts ...sql.OrderTermOption) OrderOption
ByEntityTypeField orders the results by entity_type field.
func ByFields ¶
func ByFields(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByFields orders the results by fields terms.
func ByFieldsCount ¶
func ByFieldsCount(opts ...sql.OrderTermOption) OrderOption
ByFieldsCount orders the results by fields count.
func ByGroupField ¶
func ByGroupField(field string, opts ...sql.OrderTermOption) OrderOption
ByGroupField orders the results by group field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByImportRef ¶
func ByImportRef(opts ...sql.OrderTermOption) OrderOption
ByImportRef orders the results by the import_ref field.
func ByInsured ¶
func ByInsured(opts ...sql.OrderTermOption) OrderOption
ByInsured orders the results by the insured field.
func ByLifetimeWarranty ¶
func ByLifetimeWarranty(opts ...sql.OrderTermOption) OrderOption
ByLifetimeWarranty orders the results by the lifetime_warranty field.
func ByMaintenanceEntries ¶
func ByMaintenanceEntries(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByMaintenanceEntries orders the results by maintenance_entries terms.
func ByMaintenanceEntriesCount ¶
func ByMaintenanceEntriesCount(opts ...sql.OrderTermOption) OrderOption
ByMaintenanceEntriesCount orders the results by maintenance_entries count.
func ByManufacturer ¶
func ByManufacturer(opts ...sql.OrderTermOption) OrderOption
ByManufacturer orders the results by the manufacturer field.
func ByModelNumber ¶
func ByModelNumber(opts ...sql.OrderTermOption) OrderOption
ByModelNumber orders the results by the model_number field.
func ByName ¶
func ByName(opts ...sql.OrderTermOption) OrderOption
ByName orders the results by the name field.
func ByNotes ¶
func ByNotes(opts ...sql.OrderTermOption) OrderOption
ByNotes orders the results by the notes field.
func ByParentField ¶
func ByParentField(field string, opts ...sql.OrderTermOption) OrderOption
ByParentField orders the results by parent field.
func ByPurchaseDate ¶
func ByPurchaseDate(opts ...sql.OrderTermOption) OrderOption
ByPurchaseDate orders the results by the purchase_date field.
func ByPurchaseFrom ¶
func ByPurchaseFrom(opts ...sql.OrderTermOption) OrderOption
ByPurchaseFrom orders the results by the purchase_from field.
func ByPurchasePrice ¶
func ByPurchasePrice(opts ...sql.OrderTermOption) OrderOption
ByPurchasePrice orders the results by the purchase_price field.
func ByQuantity ¶
func ByQuantity(opts ...sql.OrderTermOption) OrderOption
ByQuantity orders the results by the quantity field.
func BySerialNumber ¶
func BySerialNumber(opts ...sql.OrderTermOption) OrderOption
BySerialNumber orders the results by the serial_number field.
func BySoldDate ¶
func BySoldDate(opts ...sql.OrderTermOption) OrderOption
BySoldDate orders the results by the sold_date field.
func BySoldNotes ¶
func BySoldNotes(opts ...sql.OrderTermOption) OrderOption
BySoldNotes orders the results by the sold_notes field.
func BySoldPrice ¶
func BySoldPrice(opts ...sql.OrderTermOption) OrderOption
BySoldPrice orders the results by the sold_price field.
func BySoldTo ¶
func BySoldTo(opts ...sql.OrderTermOption) OrderOption
BySoldTo orders the results by the sold_to field.
func BySyncChildEntityLocations ¶
func BySyncChildEntityLocations(opts ...sql.OrderTermOption) OrderOption
BySyncChildEntityLocations orders the results by the sync_child_entity_locations field.
func ByTag ¶
func ByTag(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByTag orders the results by tag terms.
func ByTagCount ¶
func ByTagCount(opts ...sql.OrderTermOption) OrderOption
ByTagCount orders the results by tag count.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.
func ByWarrantyDetails ¶
func ByWarrantyDetails(opts ...sql.OrderTermOption) OrderOption
ByWarrantyDetails orders the results by the warranty_details field.
func ByWarrantyExpires ¶
func ByWarrantyExpires(opts ...sql.OrderTermOption) OrderOption
ByWarrantyExpires orders the results by the warranty_expires field.